/**************************************************************************
 |                                                                         
 |                    STATA SETUP FILE FOR ICPSR 03088
 |           ALCOHOL AND DRUG SERVICES STUDY (ADSS), 1996-1999:
 |                            [UNITED STATES]
 |       (DATASET 0007: PHASE III IN-TREATMENT METHADONE FOLLOW-UP)
 |
 |
 |  Please edit this file as instructed below.
 |  To execute, start Stata, change to the directory containing:
 |       - this do file
 |       - the ASCII data file
 |       - the dictionary file
 |
 |  Then execute the do file (e.g., do 03088-0007-statasetup.do)
 |
 **************************************************************************/

set mem 7m  /* Allocating 7 megabyte(s) of RAM for Stata SE to read the
                 data file into memory. */


set more off  /* This prevents the Stata output viewer from pausing the
                 process */

/****************************************************

Section 1: File Specifications
   This section assigns local macros to the necessary files.
   Please edit:
        "data-filename" ==> The name of data file downloaded from ICPSR
        "dictionary-filename" ==> The name of the dictionary file downloaded.
        "stata-datafile" ==> The name you wish to call your Stata data file.

   Note:  We assume that the raw data, dictionary, and setup (this do file) all
          reside in the same directory (or folder).  If that is not the case
          you will need to include paths as well as filenames in the macros.

********************************************************/

local raw_data "data-filename"
local dict "dictionary-filename"
local outfile "stata-datafile"

/********************************************************

Section 2: Infile Command

This section reads the raw data into Stata format.  If Section 1 was defined
properly, there should be no reason to modify this section.  These macros
should inflate automatically.

**********************************************************/

infile using `dict', using (`raw_data') clear


/*********************************************************

Section 3: Value Label Definitions
This section defines labels for the individual values of each variable.
We suggest that users do not modify this section.

**********************************************************/


label data "Alcohol and Drug Services Study (ADSS), 1996-1999: [United States], Phase III In-Treatment Methadone Follow-Up"

#delimit ;
label define CASEID    -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define FACID     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define FOUTCOME  -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "COMPLETE" 2 "OTHER" 3 "REFUSED" ;
label define F_CT      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "DISCHARGED" 2 "IN TREATMENT" ;
label define FA1       -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "MALE" 2 "FEMALE" ;
label define FA3       -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FA4       -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FA5       -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "WHITE" 2 "BLACK OR AFRICAN AMERICAN,"
                       3 "ASIAN,"
                       4 "NATIVE HAWAIIAN OR OTHER PACIFIC ISLANDE"
                       5 "AMERICAN INDIAN," 6 "ALASKA NATIVE"
                       96 "OTHER (NOT FURTHER SPECIFIED)" ;
label define FA6       -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "ENGLISH ONLY" 2 "SPANISH ONLY"
                       3 "OTHER LANGUAGE(S) ONLY (EXCLUDING ENGLIS"
                       4 "BOTH ENGLISH AND SPANISH"
                       5 "BOTH SPANISH AND OTHER LANGUAGE(S) (EXCL"
                       6 "BOTH ENGLISH AND OTHER LANGUAGE(S)" ;
label define FA7       -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FA8       -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES, DIPLOMA" 2 "YES, GED" 3 "NO"
                       4 "NEVER ATTENDED SCHOOL (A11)" ;
label define FA9       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "1ST GRADE"
                       2 "2ND GRADE" 3 "3RD GRADE" 4 "4TH GRADE"
                       5 "5TH GRADE" 6 "6TH GRADE" 7 "7TH GRADE"
                       8 "8TH GRADE" 9 "9TH GRADE" 10 "10TH GRADE"
                       11 "11TH GRADE" 12 "12TH GRADE"
                       13 "1 YEAR COLLEGE/TECHNICAL SCHOOL"
                       14 "2 YEARS COLLEGE/TECHNICAL SCHOOL"
                       15 "3 - YEARS COLLEGE/TECHNICAL SCHOOL"
                       16 "4 - YEARS COLLEGE/TECHNICAL SCHOOL"
                       17 "GRADUATE/PROFESSIONAL SCHOOL" ;
label define FA10      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FA11      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FA12      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FA12A     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FA13      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FA14      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FA15      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FA16      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FA17      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define FA18      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define F_LANG    -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "ENGLISH" 2 "SPANISH" ;
label define FB1A      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB2A      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB3A      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB4A      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "LESS THAN ONCE A MONTH" 2 "1 - 3 TIMES A MONTH"
                       3 "1 - 2 TIMES A WEEK" 4 "3 - 4 TIMES A WEEK"
                       5 "5 - 6 TIMES A WEEK, DAILY OR ALMOST EVER"
                       6 "2 OR MORE TIMES A DAY" ;
label define FB1B      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB2B      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB3B      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB4B      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "LESS THAN ONCE A MONTH" 2 "1 - 3 TIMES A MONTH"
                       3 "1 - 2 TIMES A WEEK" 4 "3 - 4 TIMES A WEEK"
                       5 "5 - 6 TIMES A WEEK, DAILY OR ALMOST EVER"
                       6 "2 OR MORE TIMES A DAY" ;
label define FB1C      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB2C      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB3C      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB4C      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "LESS THAN ONCE A MONTH" 2 "1 - 3 TIMES A MONTH"
                       3 "1 - 2 TIMES A WEEK" 4 "3 - 4 TIMES A WEEK"
                       5 "5 - 6 TIMES A WEEK, DAILY OR ALMOST EVER"
                       6 "2 OR MORE TIMES A DAY" ;
label define FB1D      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB2D      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB3D      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB4D      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "LESS THAN ONCE A MONTH" 2 "1 - 3 TIMES A MONTH"
                       3 "1 - 2 TIMES A WEEK" 4 "3 - 4 TIMES A WEEK"
                       5 "5 - 6 TIMES A WEEK, DAILY OR ALMOST EVER"
                       6 "2 OR MORE TIMES A DAY" ;
label define FB1E      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB2E      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB3E      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB4E      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "LESS THAN ONCE A MONTH" 2 "1 - 3 TIMES A MONTH"
                       3 "1 - 2 TIMES A WEEK" 4 "3 - 4 TIMES A WEEK"
                       5 "5 - 6 TIMES A WEEK, DAILY OR ALMOST EVER"
                       6 "2 OR MORE TIMES A DAY" ;
label define FB1F      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB2F      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB3F      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB4F      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "LESS THAN ONCE A MONTH" 2 "1 - 3 TIMES A MONTH"
                       3 "1 - 2 TIMES A WEEK" 4 "3 - 4 TIMES A WEEK"
                       5 "5 - 6 TIMES A WEEK, DAILY OR ALMOST EVER"
                       6 "2 OR MORE TIMES A DAY" ;
label define FB1G      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB2G      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB3G      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB4G      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "LESS THAN ONCE A MONTH" 2 "1 - 3 TIMES A MONTH"
                       3 "1 - 2 TIMES A WEEK" 4 "3 - 4 TIMES A WEEK"
                       5 "5 - 6 TIMES A WEEK, DAILY OR ALMOST EVER"
                       6 "2 OR MORE TIMES A DAY" ;
label define FB1H      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB2H      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB3H      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB4H      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "LESS THAN ONCE A MONTH" 2 "1 - 3 TIMES A MONTH"
                       3 "1 - 2 TIMES A WEEK" 4 "3 - 4 TIMES A WEEK"
                       5 "5 - 6 TIMES A WEEK, DAILY OR ALMOST EVER"
                       6 "2 OR MORE TIMES A DAY" ;
label define FB1I      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB2I      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB3I      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB4I      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "LESS THAN ONCE A MONTH" 2 "1 - 3 TIMES A MONTH"
                       3 "1 - 2 TIMES A WEEK" 4 "3 - 4 TIMES A WEEK"
                       5 "5 - 6 TIMES A WEEK, DAILY OR ALMOST EVER"
                       6 "2 OR MORE TIMES A DAY" ;
label define FB1J      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB2J      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB3J      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB4J      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "LESS THAN ONCE A MONTH" 2 "1 - 3 TIMES A MONTH"
                       3 "1 - 2 TIMES A WEEK" 4 "3 - 4 TIMES A WEEK"
                       5 "5 - 6 TIMES A WEEK, DAILY OR ALMOST EVER"
                       6 "2 OR MORE TIMES A DAY" ;
label define FB1K      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB2K      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB3K      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB4K      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "LESS THAN ONCE A MONTH" 2 "1 - 3 TIMES A MONTH"
                       3 "1 - 2 TIMES A WEEK" 4 "3 - 4 TIMES A WEEK"
                       5 "5 - 6 TIMES A WEEK, DAILY OR ALMOST EVER"
                       6 "2 OR MORE TIMES A DAY" ;
label define FB1L      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB2L      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB3L      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB4L      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "LESS THAN ONCE A MONTH" 2 "1 - 3 TIMES A MONTH"
                       3 "1 - 2 TIMES A WEEK" 4 "3 - 4 TIMES A WEEK"
                       5 "5 - 6 TIMES A WEEK, DAILY OR ALMOST EVER"
                       6 "2 OR MORE TIMES A DAY" ;
label define FB1M      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB1MOTH   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "DMT"
                       2 "ASTHMA MED" 3 "BARB" 4 "SMOKED CHERM"
                       5 "BLOOD PRESSURE MEDICINE" 6 "BAM"
                       7 "ANTIDEPRESSANTS" 8 "ELAVIL" 9 "PAIN KILLERS"
                       10 "CHOLORATINE" 11 "GHB" 96 "VARIES" ;
label define FB2M      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB3M      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB4M      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "LESS THAN ONCE A MONTH" 2 "1 - 3 TIMES A MONTH"
                       3 "1 - 2 TIMES A WEEK" 4 "3 - 4 TIMES A WEEK"
                       5 "5 - 6 TIMES A WEEK, DAILY OR ALMOST EVER"
                       6 "2 OR MORE TIMES A DAY" ;
label define FB5       -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB6       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "NEVER"
                       2 "LESS THAN ONCE A MONTH" 3 "1 - 3 TIMES A MONTH"
                       4 "1 - 2 TIMES A WEEK" 5 "3 - 4 TIMES A WEEK"
                       6 "DAILY OR ALMOST EVERY DAY" ;
label define FB7       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB8       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "NEVER"
                       2 "LESS THAN ONCE A MONTH" 3 "1 - 3 TIMES A MONTH"
                       4 "1 - 2 TIMES A WEEK" 5 "3 - 4 TIMES A WEEK"
                       6 "DAILY OR ALMOST EVERY DAY" ;
label define FB9       -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB9A      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB10      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB11      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "ONE DAY"
                       2 "2 - 5 DAYS" 3 "6 - 10 DAYS" 4 "11 - 20 DAYS"
                       5 "21 DAYS OR MORE" ;
label define FB12A     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB13A     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB12B     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB13B     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB12C     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB13C     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB14      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "INHALANTS," 2 "MARIJUANA OR HASHISH"
                       3 "CRACK," 4 "COCAINE, OTHER THAN CRACK"
                       5 "HALLUCINOGENS OR PSYCHEDELICS," 6 "HEROIN,"
                       7 "ILLEGAL METHADONE," 8 "OTHER OPIATES"
                       9 "AMPHETAMINES OR STIMULANTS," 10 "SEDATIVES,"
                       11 "TRANQUILIZERS," 12 "OVER-THE-COUNTER DRUGS,"
                       13 "ALCOHOL" 14 "COMBO OF 02 AND 03 AND 04 AND 13"
                       15 "COMBO OF 04 AND 06 AND 13" 16 "COMBO OF 02 AND 13"
                       17 "COMBO OF 03 AND 04 AND 13" 18 "COMBO OF 04 AND 13"
                       19 "COMBO OF 03 AND 13" 20 "COMBO OF 09 AND 10 AND 04"
                       21 "COMBO OF 02 AND 12 AND 13" 22 "DEPRESSION RX"
                       23 "COMBO OF 02 AND 08" ;
label define FB15      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 0 "NO OTHER DRUG" 1 "INHALANTS,"
                       2 "MARIJUANA OR HASHISH," 3 "CRACK,"
                       4 "COCAINE, OTHER THAN CRACK"
                       5 "HALLUCINOGENS OR PSYCHEDELICS," 6 "HEROIN,"
                       7 "ILLEGAL METHADONE," 8 "OTHER OPIATES"
                       9 "AMPHETAMINES OR STIMULANTS," 10 "SEDATIVES,"
                       11 "TRANQUILIZERS," 12 "OVER-THE-COUNTER DRUGS,"
                       13 "ALCOHOL, OR" 14 "COMBO OF 04 AND 06"
                       15 "COMBO OF 02 AND 03 AND 05 AND 11" 16 "RX DRUGS"
                       17 "PAIN PILLS" ;
label define FB16      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB17      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       0 "NOT DURING 12-MONTH PERIOD" ;
label define FB18      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB19      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       0 "NOT DURING 12-MONTH PERIOD" ;
label define FB20      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "MARRIED"
                       2 "LIVING WITH SOMEONE AS MARRIED" 3 "SEPARATED"
                       4 "DIVORCED" 5 "WIDOWED" 6 "NEVER MARRIED" ;
label define FB21      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define FB22      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB23      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB24      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB25      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "LESS THAN 1 MONTH" 2 "1 - 6 MONTHS"
                       3 "7 - 11 MONTHS" 4 "ENTIRE 12 MONTHS" ;
label define FB26      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "A SINGLE FAMILY HOUSE, DUPLEX OR"
                       2 "AN APARTMENT, CONDO, OR OTHER MULTI-FAMI"
                       3 "A MOBILE HOME OR TRAILER,"
                       4 "A HOTEL, MOTEL, ROOMING HOUSE, OR BOARDI"
                       5 "A HOSPITAL OR MEDICAL INSTITUTION,"
                       6 "JAIL OR PRISON,"
                       7 "A RESIDENTIAL DRUG OR ALCOHOL TX PROGRAM"
                       8 "A HOMELESS SHELTER," 9 "A HALFWAY HOUSE,"
                       10 "ON THE STREET, OR" 11 "TRANSIENT" 12 "GROUP HOME"
                       13 "FRIENDS HOUSE" 14 "COMBO OF 01 AND 06" 15 "CHURCH"
                       16 "PRERELEASE CENTER" 17 "BATTERED WOMENS SHELTER"
                       18 "COMBO 04 AND 08 AND 10"
                       19 "COMBO OF 01 AND 06 AND 10"
                       20 "COMMUNITY FOR PRIESTS" 21 "CAR"
                       22 "DIFFERENT FAMILY MEMBERS" 23 "TRUCK SLEEPER BERTH"
                       24 "PAROLE PROGRAM" 25 "DRINKING FRIENDS" ;
label define FB27A     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB27B     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB27C     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB27D     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB27E     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB27F     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB27G     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB28      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB29      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "LESS THAN ONE YEAR," 2 "1 TO 2 YEARS,"
                       3 "MORE THAN 2 YEARS BUT LESS THAN 5 YEARS"
                       4 "FIVE YEARS OR MORE?" ;
label define FB30      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB31      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB32      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "CLERICAL WORKER" 2 "SALES WORKER"
                       3 "SERVICE WORKER" 4 "PRIVATE HH WORKER"
                       5 "SKILLED WORKER OR CRAFTSMEN" 6 "LABORER"
                       7 "OPERATOR OR MACHINE OPERATOR"
                       8 "TRANSPORTATION EQUIPMENT OPERATOR" 9 "FARM LABORER"
                       10 "FARMER OR FARM MANAGER" 11 "MANAGER/ADMINISTRATOR"
                       12 "LAY COUNSELOR, PEER COUNSELOR"
                       13 "PROFESSIONAL/TECHNICAL" 96 "OTHER, UNABLE TO CODE" ;
label define FB33A     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "PER HOUR"
                       2 "EVERY WEEK" 3 "EVERY TWO WEEKS" 4 "PER MONTH"
                       5 "PER YEAR" 6 "OTHER (SPECIFY)" ;
label define FB33AOTH  -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "NIGHT"
                       2 "DAY" 3 "3 MONTHS" 4 "TIP"
                       5 "NOT ENOUGH BUSINESS TO MAKE A PROFIT"
                       6 "PER 12 HOUR SHIFT" 7 "9 MONTHS" 8 "PER HEAD" ;
label define FB34      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB34A     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "LESS THAN ONE YEAR," 2 "1 TO 2 YEARS"
                       3 "MORE THAN 2 YEARS BUT LESS THAN 5 YEARS"
                       4 "FIVE YEARS OR MORE?" ;
label define FB35      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB36      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB37      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "CLERICAL WORKER" 2 "SALES WORKER"
                       3 "SERVICE WORKER" 4 "PRIVATE HH WORKER"
                       5 "SKILLED WORKER OR CRAFTSMEN" 6 "LABORER"
                       7 "OPERATOR OR MACHINE OPERATOR"
                       8 "TRANSPORTATION EQUIPMENT OPERATOR" 9 "FARM LABORER"
                       10 "FARMER OR FARM MANAGER" 11 "MANAGER/ADMINISTRATOR"
                       12 "LAY COUNSELOR, PEER COUNSELOR"
                       13 "PROFESSIONAL/TECHNICAL" 96 "OTHER, UNABLE TO CODE" ;
label define FB38A     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "PER HOUR"
                       2 "EVERY WEEK" 3 "EVERY TWO WEEKS" 4 "PER MONTH"
                       5 "PER YEAR" 6 "OTHER (SPECIFY)" ;
label define FB38AOTH  -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "PER JOB"
                       2 "PER NIGHT" 3 "PER 6 DAYS" 4 "PER POUND"
                       7 "SEMESTER" 8 "VOLUNTEERED" 9 "A DAY" 10 "WEEKEND"
                       11 "PER PARTY" ;
label define FB39      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB40      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "LESS THAN ONE YEAR," 2 "1 TO 2 YEARS,"
                       3 "MORE THAN 2 YEARS BUT LESS THAN 5 YEARS"
                       4 "FIVE YEARS OR MORE?" ;
label define FB41      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB42A     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB42B     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB42C     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB42D     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB42E     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB42F     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB42G     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB42H     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB42I     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB42J     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB42K     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB42L     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB43      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB44      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "LESS THAN $20,000" 2 "$20,000 OR MORE" ;
label define FB44A     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "LESS THAN $1,000 (INCLUDING LOSS)"
                       2 "$1,000 - $1,999" 3 "$2,000 - $2,999"
                       4 "$3,000 - $3,999" 5 "$4,000 - $4,999"
                       6 "$5,000 - $5,999" 7 "$6,000 - $6,999"
                       8 "$7,000 - $7,999" 9 "$8,000 - $8,999"
                       10 "$9,000 - $9,999" 11 "$10,000 - $10,999"
                       12 "$11,000 - $11,999" 13 "$12,000 - $12,999"
                       14 "$13,000 - $13,999" 15 "$14,000 - $14,999"
                       16 "$15,000 - $15,999" 17 "$16,000 - $16,999"
                       18 "$17,000 - $17,999" 19 "$18,000 - $18,999"
                       20 "$19,000 - $19,999" ;
label define FB44B     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       21 "$20,000 - $24,999" 22 "$25,000 - $29,999"
                       23 "$30,000 - $34,999" 24 "$35,000 - $39,999"
                       25 "$40,000 - $44,999" 26 "$45,000 - $49,999"
                       27 "$50,000 - $74,999" 28 "$75,000 OR MORE" ;
label define FB45      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB46A     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       0 "THIS TREATMENT NOT USED" ;
label define FB47A     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB46B     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       0 "THIS TREATMENT NOT USED" ;
label define FB47B     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB46C     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       0 "THIS TREATMENT NOT USED" ;
label define FB47C     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB46D     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       0 "THIS TREATMENT NOT USED" ;
label define FB47D     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB46E     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       0 "THIS TREATMENT NOT USED" ;
label define FB47E     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB46F     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       0 "THIS TREATMENT NOT USED" ;
label define FB47F     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB46G     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       0 "THIS TREATMENT NOT USED" ;
label define FB47G     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB46H     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       0 "THIS TREATMENT NOT USED" ;
label define FB47H     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB48A     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       0 "THIS TREATMENT NOT USED" ;
label define FB49A     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB48B     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       0 "THIS TREATMENT NOT USED" ;
label define FB49B     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB48C     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       0 "THIS TREATMENT NOT USED" ;
label define FB49C     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB48D     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       0 "THIS TREATMENT NOT USED" ;
label define FB49D     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB48E     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       0 "THIS TREATMENT NOT USED" ;
label define FB49E     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB48F     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       0 "THIS TREATMENT NOT USED" ;
label define FB49F     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB48G     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       0 "THIS TREATMENT NOT USED" ;
label define FB49G     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB48H     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       0 "THIS TREATMENT NOT USED" ;
label define FB49H     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB50A     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB50B     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB50C     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB50D     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB51A     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB52A     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB53A     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "LESS THAN ONCE A MONTH OR INFREQUENTLY"
                       2 "ONCE A MONTH" 3 "TWO TO THREE TIMES A MONTH"
                       4 "ONCE A WEEK" 5 "ONE TO TWO TIMES A WEEK"
                       6 "DAILY OR ALMOST DAILY" ;
label define FB51B     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB52B     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB53B     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "LESS THAN ONCE A MONTH OR INFREQUENTLY"
                       2 "ONCE A MONTH" 3 "TWO TO THREE TIMES A MONTH"
                       4 "ONCE A WEEK" 5 "ONE TO TWO TIMES A WEEK"
                       6 "DAILY OR ALMOST DAILY" ;
label define FB51C     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB52C     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB53C     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "LESS THAN ONCE A MONTH OR INFREQUENTLY"
                       2 "ONCE A MONTH" 3 "TWO TO THREE TIMES A MONTH"
                       4 "ONCE A WEEK" 5 "ONE TO TWO TIMES A WEEK"
                       6 "DAILY OR ALMOST DAILY" ;
label define FB51D     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB52D     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB53D     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "LESS THAN ONCE A MONTH OR INFREQUENTLY"
                       2 "ONCE A MONTH" 3 "TWO TO THREE TIMES A MONTH"
                       4 "ONCE A WEEK" 5 "ONE TO TWO TIMES A WEEK"
                       6 "DAILY OR ALMOST DAILY" ;
label define FB54      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB55      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB56      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB57      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB58      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB59      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB60      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "EXCELLENT," 2 "GOOD," 3 "FAIR, OR"
                       4 "POOR?" ;
label define FB61      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB62      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB63      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB64A     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB65A     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB64B     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB65B     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB64C     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB65C     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB64D     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB65D     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB64E     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB65E     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB64F     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB65F     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB64G     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB65G     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB64H     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB65H     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB64I     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB65I     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB64J     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB65J     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB64K     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB65K     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB64L     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB65L     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB64M     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB65M     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB66      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB67      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB68      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB69      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB70      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB71      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB72      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define FB73      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define FB74      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define FB75      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB76      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "LESS THAN 1/4 PACK A DAY (1-5 CIGARETTES"
                       2 "ABOUT 1/2 PACK A DAY (6-15 CIGARETTES)"
                       3 "ABOUT A PACK A DAY (16-25 CIGARETTES)"
                       4 "ABOUT 1 1/2 PACKS A DAY (26-35 CIGARETTE"
                       5 "ABOUT 2 PACKS OR MORE A DAY (OVER 35 CIG" ;
label define FB77A     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB77B     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB77C     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB78      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB78A     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB79      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 0 "NONE" 1 "ONE" 2 "2 - 10" 3 "11 - 25"
                       4 "26 - 100" 5 "101 - 500" 6 "MORE THAN 500" ;
label define FB80      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB81A     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB82A     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB83A     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB84A     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB85A     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB81B     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB82B     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB83B     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB84B     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB85B     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB81C     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB82C     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB83C     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB84C     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB85C     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB81D     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB82D     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB83D     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB84D     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB85D     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB81E     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB82E     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB83E     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB84E     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB85E     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB81F     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB82F     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB83F     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB84F     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB85F     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB81G     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB82G     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB83G     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB84G     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB85G     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB81H     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB82H     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB83H     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB84H     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB85H     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB81I     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB82I     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB83I     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB84I     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB85I     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB81J     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB82J     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB83J     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB84J     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB85J     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB81K     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB82K     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB83K     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB84K     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB85K     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB81L     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB82L     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB83L     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB84L     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB85L     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB81M     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB82M     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB83M     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB84M     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB85M     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB81N     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB81NOTH  -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSSING" -4 "OTHER"
                       1 "PROBATION VIOLATION" 2 "WEAPON/WEAPON OFFENSES"
                       3 "NO ARREST" 4 "GAMBLING" 5 "PAROLE VIOLATION"
                       6 "WARRANTS ISSUED" 7 "CONTEMPT OF COURT"
                       8 "TAX EVASION" 9 "VANDALISM"
                       10 "DRIVING WITHOUT LICENSE" 11 "NON COMPLIANCE"
                       12 "UNDERAGE DRINKING" 13 "INCITING A RIOT"
                       14 "NUMBER RUNNER" 15 "TRESPASS" 16 "DEPRESSION"
                       17 "CHILD SUPPORT" 18 "RESISTING ARREST"
                       19 "TRAFFIC TICKET" 20 "BACK FINES"
                       21 "MOVING GUNS ACROSS STATE LINES"
                       22 "TERRORIST THREAT"
                       23 "VIOLATION OF ORDER OF PROTECTION"
                       24 "FAILURE TO PAY SUBWAY FARE" 25 "ARSON"
                       26 "DIDN'T GO TO AFTERCARE" ;
label define FB82N     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB83N     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB84N     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB85N     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB86      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB87      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB88      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB89      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB90      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 0 "NONE" ;
label define FB91      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "LESS THAN OR EQUAL TO ONE DAY" ;
label define FB91U     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "DAYS"
                       2 "WEEKS" 3 "MONTHS" ;
label define FB92      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB93      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB93U     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "WEEKS"
                       2 "MONTHS" 3 "YEARS" ;
label define FB94      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB95      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FB95A     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC1       -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "INHALANTS," 2 "MARIJUANA OR HASHISH,"
                       3 "CRACK," 4 "COCAINE,"
                       5 "HALLUCINOGENS OR PSYCHEDELICS," 6 "HEROIN,"
                       7 "ILLEGAL METHADONE," 8 "OTHER OPIATES,"
                       9 "AMPHETAMINES OR STIMULANTS," 10 "SEDATIVES,"
                       11 "TRANQUILIZERS," 12 "OVER-THE-COUNTER DRUGS,"
                       13 "ALCOHOL, OR" 14 "COMBO OF 04 AND 06"
                       15 "COMBO OF 02 AND 13" 16 "COMBO OF 03 AND 13"
                       17 "NO DRUG OR ALCOHOL PROBLEM"
                       18 "COMBO OF 02 AND 03 AND 09"
                       19 "COMBO OF 09 AND 10 AND 11" 20 "NONE"
                       21 "COMBO OF 03 AND 04" 22 "COMBO OF 02 AND 06"
                       23 "PAIN KILLERS"
                       96 "SOME OTHER DRUG? (NOT FURTHER SPECIFIED" ;
label define FC2       -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 0 "NO OTHER DRUG" 1 "INHALANTS,"
                       2 "MARIJUANA OR HASHISH," 3 "CRACK," 4 "COCAINE,"
                       5 "HALLUCINOGENS OR PSYCHEDELICS," 6 "HEROIN,"
                       7 "ILLEGAL METHADONE," 8 "OTHER OPIATES,"
                       9 "AMPHETAMINES OR STIMULANTS," 10 "SEDATIVES,"
                       11 "TRANQUILIZERS," 12 "OVER-THE-COUNTER DRUGS,"
                       13 "ALCOHOL, OR" 14 "COMBO OF 09 AND 13"
                       15 "COMBO OF 01 AND 02" 16 "RX DRUGS" ;
label define FC3       -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC4       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "INHALANTS,"
                       2 "MARIJUANA OR HASHISH," 3 "CRACK," 4 "COCAINE,"
                       5 "HALLUCINOGENS OR PSYCHEDELICS," 6 "HEROIN,"
                       7 "ILLEGAL METHADONE," 8 "OTHER OPIATES,"
                       9 "AMPHETAMINES OR STIMULANTS," 10 "SEDATIVES,"
                       11 "TRANQUILIZERS," 12 "COMBO OF 04, 06 AND 13"
                       13 "ALCOHOL, OR" 14 "COMBO OF 02 AND 03 AND 06 AND 11"
                       15 "COMBO OF 03 AND 13" ;
label define FC5       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       0 "NO OTHER DRUG" 1 "INHALANTS,"
                       2 "MARIJUANA OR HASHISH," 3 "CRACK," 4 "COCAINE,"
                       5 "HALLUCINOGENS OR PSYCHEDELICS," 6 "HEROIN,"
                       7 "ILLEGAL METHADONE," 8 "OTHER OPIATES,"
                       9 "AMPHETAMINES OR STIMULANTS," 10 "SEDATIVES,"
                       11 "TRANQUILIZERS," 12 "OVER-THE-COUNTER DRUGS,"
                       13 "ALCOHOL, OR" 15 "CHLONODINE" 17 "TOBACCO"
                       20 "COMBO OF 02 AND 03 AND 04"
                       96 "SOME OTHER DRUG? (NOT FURTHER SPECIFIED" ;
label define FC6       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC6A      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC7A      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC7B      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC7C      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC7D      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC7E      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC7F      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC8       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "TOO HIGH"
                       2 "THE RIGHT AMOUNT" 3 "TOO LOW" ;
label define FC8A      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC9       -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC10      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC11      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       0 "LESS THAN ONE" ;
label define FC11U     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "DAYS"
                       2 "WEEKS" 3 "MONTHS" 4 "YEARS" ;
label define FC12      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "CLERICAL WORKER" 2 "SALES WORKER"
                       3 "SERVICE WORKER" 4 "PRIVATE HH WORKER"
                       5 "SKILLED WORKER OR CRAFTSMEN" 6 "LABORER"
                       7 "OPERATOR OR MACHINE OPERATOR"
                       8 "TRANSPORTATION EQUIPMENT OPERATOR" 9 "FARM LABORER"
                       10 "FARMER OR FARM MANAGER" 11 "MANAGER/ADMINISTRATOR"
                       12 "LAY COUNSELOR, PEER COUNSELOR"
                       13 "PROFESSIONAL/TECHNICAL" 14 "SELF EMPLOYED"
                       15 "MILITARY" 96 "OTHER, UNABLE TO CODE" ;
label define FC13A     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "PER HOUR"
                       2 "EVERY WEEK" 3 "EVERY TWO WEEKS" 4 "PER MONTH"
                       5 "PER YEAR" 6 "OTHER (SPECIFY)" ;
label define FC13AOTH  -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 2 "3 MONTHS"
                       3 "PER DAY" 4 "PER HEAD" 5 "NO PROFIT"
                       6 "PER 12 HOUR SHIFT" 7 "VARIED-PAID BY JOB"
                       8 "PER NIGHT" 9 "EVERY 2 WKS PLUS COMMISSION"
                       10 "PIECEWORK" ;
label define FC14      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC15      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FC15U     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "DAYS"
                       2 "WEEKS" 3 "MONTHS" 4 "YEARS" ;
label define FC16A     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "PER HOUR"
                       2 "EVERY WEEK" 3 "EVERY TWO WEEKS" 4 "PER MONTH"
                       5 "PER YEAR" 6 "OTHER (SPECIFY)" ;
label define FC16AOTH  -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "GAIN PROGRAM" 2 "WORKED EVERY DAY" 3 "VOLUNTEER"
                       4 "PER DAY" 5 "DURING TREATMENT" 6 "PER JOB"
                       7 "VARIES" 8 "PER NIGHT" 9 "FOR 6 DAYS" 10 "NO PAY" ;
label define FC17      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC18      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "RECEIVE TX ON AN OP BASIS ONLY"
                       2 "ONLY STAY OVERNIGHT SUCH AS RES TX ONLY"
                       3 "RECEIVE RES TX AND AN OP PERIOD OF CARE?" ;
label define FC19      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FC20      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "LESS THAN ONCE A MONTH," 2 "ONCE A MONTH,"
                       3 "TWO TO THREE TIMES A MONTH," 4 "ONCE A WEEK,"
                       5 "TWICE A WEEK," 6 "THREE TIMES A WEEK,"
                       7 "FOUR TIMES A WEEK," 8 "FIVE TIMES A WEEK,"
                       9 "SIX TIMES A WEEK," 10 "SEVEN TIMES A WEEK, OR"
                       11 "ONE TIME" 12 "13WK AT 5X WK 4 1/2 MONTH AT 1 WK"
                       13 "LOCK DOWN" 14 "5 DAYS DOWN TO 2"
                       15 "7 DAYS DOWN TO 3" 16 "VARIED"
                       17 "IN HOME SESSIONS" 18 "FOR 6 DAYS" 19 "5 DAYS"
                       20 "3X" 21 "2X WK THEN 5X WK" 22 "78 VISITS"
                       23 "ALL THE TIME" 24 "INPATIENT" 25 "NEVER"
                       26 "2X - 6X WK" 27 "ONLY TWICE" 28 "4X - 7X WK"
                       29 "PHONE" 30 "20 HOURS" ;
label define FC21      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "LESS THAN ONCE A MONTH," 2 "ONCE A MONTH,"
                       3 "TWO TO THREE TIMES A MONTH," 4 "ONCE A WEEK,"
                       5 "TWICE A WEEK," 6 "THREE TIMES A WEEK,"
                       7 "FOUR TIMES A WEEK," 8 "FIVE TIMES A WEEK,"
                       9 "SIX TIMES A WEEK," 10 "SEVEN TIMES A WEEK, OR"
                       11 "MORE THAN 7X A WEEK" 12 "TWICE"
                       13 "JUST TREATMENT" 14 "20 HOURS" 15 "NONE" 16 "3X"
                       17 "ONE TIME" 18 "VARIOUS HOURS TO COMPLETE 20 HOURS"
                       19 "5 DAYS" ;
label define FC22      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER"
                       1 "FEELING PRESSURED BY JUDGE, PAROLE/PROBA"
                       2 "PRESSURE FROM A SPOUSE, PARTNER, OR PARE"
                       3 "PRESSURE FROM A SCHOOL TEACHER, MINISTER"
                       4 "TO GET, KEEP, OR IMPROVE A JOB SITUATION"
                       5 "TO GET OR KEEP CUSTODY OF ONE OR MORE CH"
                       6 "TO BECOME A BETTER PARENT,"
                       7 "ANY PROBLEMS YOU HAD WITH YOUR HEALTH TH"
                       8 "NEEDED/WANTED TO BECOME ELIG. FOR SOME T"
                       9 "WANTED TO CHANGE OR IMPROVE YOURSELF,"
                       10 "REQUIRED TO ATTEND TX AS CONDITION OF RE"
                       11 "DIFFICULTY GETTING DRUGS,"
                       12 "FINANCIAL PROBLEMS OR COULDNT AFFORD TO"
                       13 "ONLY TREATMENT AVAILABLE"
                       14 "TO OBTAIN DRIVER LICENSE"
                       15 "WIFES MENTAL ILLNESS" 16 "REFERRED TO HOSPITAL"
                       17 "FAILED DRUG TEST" 18 "DOCTOR SENT RESPONDENT"
                       19 "FAMILY SERVICE" 20 "NONE"
                       21 "NEED SOMEWHERE TO STAY" 22 "TRIED IT"
                       23 "TO BE WITH GIRLFRIEND" 24 "USED BAD DOPE"
                       25 "GET HELP WITH ADDICTION" 26 "TRANSFERRED"
                       27 "KEEP FROM BEING SICK" 28 "NEED METHADONE"
                       29 "WANTED TO STOP DRINKING"
                       30 "NORTH COAST HOUSE CONNIVED AGAINST ME HA"
                       32 "NEEDED SUPPORT EMOTIONALLY" 33 "COUNSELING"
                       34 "TIRED OF SELLING DRUGS, NO SLEEP BECAUSE"
                       35 "RELAPSE" 36 "TIRED OF GOING TO JAIL"
                       37 "FACILITY CLOSER TO HOME" 38 "SENT BY HOSPITAL"
                       39 "EMOTIONALLY FALL APART" 40 "GRIEF"
                       41 "DRUG ADDICTION" 42 "INSURANCE"
                       43 "MOMS ALCOHOL PROBLEM"
                       44 "CANT AFFORD METH. PROGRAM"
                       45 "WANTED LONG TERM TREATMENT"
                       46 "FACILITY COULDNT HANDLE PROBLEM"
                       47 "DIFFICULT TO WITHDRAW" ;
label define FC24A     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC25A     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "FACILITY"
                       2 "ELSEWHERE" ;
label define FC24B     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC25B     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "FACILITY"
                       2 "ELSEWHERE" ;
label define FC24C     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC25C     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "FACILITY"
                       2 "ELSEWHERE" ;
label define FC24D     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC25D     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "FACILITY"
                       2 "ELSEWHERE" ;
label define FC24E     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC25E     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "FACILITY"
                       2 "ELSEWHERE" ;
label define FC24F     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC25F     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "FACILITY"
                       2 "ELSEWHERE" ;
label define FC24G     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC25G     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "FACILITY"
                       2 "ELSEWHERE" ;
label define FC24H     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC25H     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "FACILITY"
                       2 "ELSEWHERE" ;
label define FC24I     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC25I     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "FACILITY"
                       2 "ELSEWHERE" ;
label define FC24J     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC25J     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "FACILITY"
                       2 "ELSEWHERE" ;
label define FC24K     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC25K     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "FACILITY"
                       2 "ELSEWHERE" ;
label define FC24L     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC25L     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "FACILITY"
                       2 "ELSEWHERE" ;
label define FC24M     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC25M     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "FACILITY"
                       2 "ELSEWHERE" ;
label define FC24N     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC25N     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "FACILITY"
                       2 "ELSEWHERE" ;
label define FC24O     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC25O     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "FACILITY"
                       2 "ELSEWHERE" ;
label define FC24P     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC25P     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "FACILITY"
                       2 "ELSEWHERE" ;
label define FC24Q     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC25Q     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "FACILITY"
                       2 "ELSEWHERE" ;
label define FC24R     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC25R     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "FACILITY"
                       2 "ELSEWHERE" ;
label define FC24S     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC25S     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "FACILITY"
                       2 "ELSEWHERE" ;
label define FC24T     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC25T     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "FACILITY"
                       2 "ELSEWHERE" ;
label define FC26      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "LESS THAN ONCE A MONTH,"
                       2 "ONE TO 3 TIMES A MONTH,"
                       3 "ONE TO 2 TIMES A WEEK, OR" 4 "MORE OFTEN?" ;
label define FC27      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "LESS THAN ONCE A MONTH,"
                       2 "ONE TO 3 TIMES A MONTH," 3 "ONE TO 2 TIMES A WEEK,"
                       4 "MORE OFTEN?" ;
label define FC28      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "VERY HELPFUL" 2 "SOMEWHAT HELPFUL, OR"
                       3 "NOT AT ALL HELPFUL?" ;
label define FC29A     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC29B     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC29C     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC29D     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC29E     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC29F     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC29G     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC29H     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC29I     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC29J     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC29K     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC29L     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC29M     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC29N     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC29O     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC30A     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC30B     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC30C     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC30D     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC30E     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC30EOTH  -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSSING" -4 "OTHER"
                       1 "WEEKLY OVERNIGHT STAY" 2 "HOUSING"
                       3 "STAY WITH TREATMENT"
                       4 "PAMPHLETS & JOURNALS TO WRITE OUT FEELINGS"
                       5 "HOUSING REFERRAL AND MEDS."
                       6 "EAT HEALTH, EXERCISE, REST" 7 "VOLUNTEER PROGRAM"
                       8 "HOME COUNSELING" 9 "HIV CLINIC"
                       10 "RELAXATION TAPES" 11 "STILL IN TREATMENT"
                       12 "FREE AIDS TESTING" 13 "DIDN'T GO BACK" ;
label define FC31A     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC32A     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FC33A     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "LESS THAN ONCE A MONTH OR INFREQUENTLY"
                       2 "ONCE A MONTH" 3 "TWO TO THREE TIMES A MONTH"
                       4 "ONCE A WEEK" 5 "ONE TO TWO TIMES A WEEK"
                       6 "DAILY OR ALMOST DAILY" ;
label define FC31B     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC32B     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FC33B     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "LESS THAN ONCE A MONTH OR INFREQUENTLY"
                       2 "ONCE A MONTH" 3 "TWO TO THREE TIMES A MONTH"
                       4 "ONCE A WEEK" 5 "ONE TO TWO TIMES A WEEK"
                       6 "DAILY OR ALMOST DAILY" ;
label define FC31C     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC32C     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FC33C     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "LESS THAN ONCE A MONTH OR INFREQUENTLY"
                       2 "ONCE A MONTH" 3 "TWO TO THREE TIMES A MONTH"
                       4 "ONCE A WEEK" 5 "ONE TO TWO TIMES A WEEK"
                       6 "DAILY OR ALMOST DAILY" ;
label define FC31D     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC32D     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FC33D     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "LESS THAN ONCE A MONTH OR INFREQUENTLY"
                       2 "ONCE A MONTH" 3 "TWO TO THREE TIMES A MONTH"
                       4 "ONCE A WEEK" 5 "ONE TO TWO TIMES A WEEK"
                       6 "DAILY OR ALMOST DAILY" ;
label define FC34      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC35      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "ONE TIME ONLY,"
                       2 "MORE THAN ONCE AT REGULAR INTERVALS,"
                       3 "MORE THAN ONCE, RANDOMLY,"
                       4 "MORE THAN ONCE, AT REGULAR INTERVALS AND"
                       5 "SOME OTHER TIMING?" ;
label define FC35OTH   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "AFTER HOME VISITS" 2 "2 TIMES ONLY"
                       3 "IF WENT OUTSIDE FACILITY" 4 "ONLY IF OUT ON A PASS" ;
label define FC36      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "EXCELLENT" 2 "GOOD" 3 "FAIR" 4 "POOR" ;
label define FC37      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC38      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC39      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC40      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC41      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC42      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC43      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC44      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC45      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC46      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define FC47      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC48      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC49      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC50      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC51      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC52      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC53      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC54      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FC55      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC56      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC57      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FC58      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FC58U     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "NUMBER OF DAYS" 2 "NUMBER OF WEEKS"
                       3 "NUMBER OF MONTHS" 4 "NUMBER OF YEARS" ;
label define FC59      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC60A     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC60B     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC60C     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC60D     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC60E     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC60F     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC61A     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "CIRCLED" 2 "NOT CIRCLED" ;
label define FC61B     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "CIRCLED" 2 "NOT CIRCLED" ;
label define FC61C     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "CIRCLED" 2 "NOT CIRCLED" ;
label define FC61D     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "CIRCLED" 2 "NOT CIRCLED" ;
label define FC61E     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "CIRCLED" 2 "NOT CIRCLED" ;
label define FC61F     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "CIRCLED" 2 "NOT CIRCLED" ;
label define FC61G     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "CIRCLED" 2 "NOT CIRCLED" ;
label define FC61H     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "CIRCLED" 2 "NOT CIRCLED" ;
label define FC61I     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "CIRCLED" 2 "NOT CIRCLED" ;
label define FC61J     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "CIRCLED" 2 "NOT CIRCLED" ;
label define FC61JOTH  -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "WORKMANS COMP" 2 "UNEMPLOYMENT"
                       3 "MEDICAID OR MEDICAL ASSISTANCE" 4 "ADASA"
                       5 "SCHOLARSHIPS" 6 "HEALTH PLAN" 7 "FOOD STAMPS"
                       8 "90 DAY PROGRAM THAT PAID" 9 "D.C. GOVT" 10 "GRANT"
                       11 "DAS" 12 "COUPON" 13 "SEMSAS" 14 "STATE" 15 "UNION"
                       16 "WELFARE" 17 "PRIVATE FOUNDATION" 18 "SENT A BILL"
                       19 "M.I.A" 20 "CPS" 21 "TAPS" 22 "CAL OPTA" 23 "S.S.I"
                       24 "GOVERNMENT GRANT" 25 "JOB PAID"
                       26 "BLUE AND TENN CARE" 27 "COUNTY" 28 "TARGET CITY"
                       29 "PENDING" 30 "LADY PAID" 31 "STATE OF TEXAS"
                       32 "HEALTH SOURCE" 33 "TRIBE/INDIAN HEALTH CARE"
                       34 "HRS" 35 "WORKED THERE" 36 "90% OF UNEMPLOYMENT"
                       37 "GROUP" 38 "R.R" 39 "STATE GRANT"
                       40 "PRIVATE DONATIONS" 41 "MED. PROGRAM"
                       42 "TOTAL HEALTH" 43 "ACT 151 STATE" 44 "ADAP"
                       45 "SECURITY BLUE" 46 "STATE SLOT" ;
label define FC61MAIN  -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "A. PRIVATE HMO OR OTHER MANAGED CARE PL"
                       2 "B. OTHER PRIVATE HEALTH INSURANCE"
                       3 "C. MEDICAID OR MEDICAL ASSISTANCE" 4 "D. MEDICARE"
                       5 "E. MILITARY HEALTH CARE (CHAMPUS,CHAMPV"
                       6 "F. CRIMINAL JUSTICE SYSTEM" 7 "G. SOCIAL SERVICES"
                       8 "H. YOUR OWN MONEY" 9 "I. NO PAYMENT"
                       96 "J. OTHER PAY" ;
label define FC62A     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC62B     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC62C     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC62D     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC62E     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC62F     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC62G     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC62H     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC62I     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC62J     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC62K     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FC62L     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD1A      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD2A      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "LESS THAN ONCE A MONTH" 2 "1 - 3 TIMES A MONTH"
                       3 "1 - 2 TIMES A WEEK" 4 "3 - 4 TIMES A WEEK"
                       5 "5 - 6 TIMES A WEEK, DAILY OR ALMOST EVER"
                       6 "2 OR MORE TIMES A DAY" ;
label define FD3A      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FD4A      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "WITHIN THE PAST 3 DAYS"
                       2 "WITHIN THE PAST WEEK BUT NOT WITHIN THE"
                       3 "MORE THAN 1 WEEK AGO BUT WITHIN THE PAST"
                       4 "1 - 6 MONTHS AGO" 5 "MORE THAN 6 MONTHS AGO" ;
label define FD1B      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD2B      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "LESS THAN ONCE A MONTH" 2 "1 - 3 TIMES A MONTH"
                       3 "1 - 2 TIMES A WEEK" 4 "3 - 4 TIMES A WEEK"
                       5 "5 - 6 TIMES A WEEK, DAILY OR ALMOST EVER"
                       6 "2 OR MORE TIMES A DAY" ;
label define FD3B      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FD4B      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "WITHIN THE PAST 3 DAYS"
                       2 "WITHIN THE PAST WEEK BUT NOT WITHIN THE"
                       3 "MORE THAN 1 WEEK AGO BUT WITHIN THE PAST"
                       4 "1 - 6 MONTHS AGO" 5 "MORE THAN 6 MONTHS AGO" ;
label define FD1C      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD2C      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "LESS THAN ONCE A MONTH" 2 "1 - 3 TIMES A MONTH"
                       3 "1 - 2 TIMES A WEEK" 4 "3 - 4 TIMES A WEEK"
                       5 "5 - 6 TIMES A WEEK, DAILY OR ALMOST EVER"
                       6 "2 OR MORE TIMES A DAY" ;
label define FD3C      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FD4C      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "WITHIN THE PAST 3 DAYS"
                       2 "WITHIN THE PAST WEEK BUT NOT WITHIN THE"
                       3 "MORE THAN 1 WEEK AGO BUT WITHIN THE PAST"
                       4 "1 - 6 MONTHS AGO" 5 "MORE THAN 6 MONTHS AGO" ;
label define FD1D      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD2D      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "LESS THAN ONCE A MONTH" 2 "1 - 3 TIMES A MONTH"
                       3 "1 - 2 TIMES A WEEK" 4 "3 - 4 TIMES A WEEK"
                       5 "5 - 6 TIMES A WEEK, DAILY OR ALMOST EVER"
                       6 "2 OR MORE TIMES A DAY" ;
label define FD3D      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FD4D      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "WITHIN THE PAST 3 DAYS"
                       2 "WITHIN THE PAST WEEK BUT NOT WITHIN THE"
                       3 "MORE THAN 1 WEEK AGO BUT WITHIN THE PAST"
                       4 "1 - 6 MONTHS AGO" 5 "MORE THAN 6 MONTHS AGO" ;
label define FD1E      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD2E      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "LESS THAN ONCE A MONTH" 2 "1 - 3 TIMES A MONTH"
                       3 "1 - 2 TIMES A WEEK" 4 "3 - 4 TIMES A WEEK"
                       5 "5 - 6 TIMES A WEEK, DAILY OR ALMOST EVER"
                       6 "2 OR MORE TIMES A DAY" ;
label define FD3E      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FD4E      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "WITHIN THE PAST 3 DAYS"
                       2 "WITHIN THE PAST WEEK BUT NOT WITHIN THE"
                       3 "MORE THAN 1 WEEK AGO BUT WITHIN THE PAST"
                       4 "1 - 6 MONTHS AGO" 5 "MORE THAN 6 MONTHS AGO" ;
label define FD1F      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD2F      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "LESS THAN ONCE A MONTH" 2 "1 - 3 TIMES A MONTH"
                       3 "1 - 2 TIMES A WEEK" 4 "3 - 4 TIMES A WEEK"
                       5 "5 - 6 TIMES A WEEK, DAILY OR ALMOST EVER"
                       6 "2 OR MORE TIMES A DAY" ;
label define FD3F      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FD4F      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "WITHIN THE PAST 3 DAYS"
                       2 "WITHIN THE PAST WEEK BUT NOT WITHIN THE"
                       3 "MORE THAN 1 WEEK AGO BUT WITHIN THE PAST"
                       4 "1 - 6 MONTHS AGO" 5 "MORE THAN 6 MONTHS AGO" ;
label define FD1G      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD2G      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "LESS THAN ONCE A MONTH" 2 "1 - 3 TIMES A MONTH"
                       3 "1 - 2 TIMES A WEEK" 4 "3 - 4 TIMES A WEEK"
                       5 "5 - 6 TIMES A WEEK, DAILY OR ALMOST EVER"
                       6 "2 OR MORE TIMES A DAY" ;
label define FD3G      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FD4G      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "WITHIN THE PAST 3 DAYS"
                       2 "WITHIN THE PAST WEEK BUT NOT WITHIN THE"
                       3 "MORE THAN 1 WEEK AGO BUT WITHIN THE PAST"
                       4 "1 - 6 MONTHS AGO" 5 "MORE THAN 6 MONTHS AGO" ;
label define FD1H      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD2H      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "LESS THAN ONCE A MONTH" 2 "1 - 3 TIMES A MONTH"
                       3 "1 - 2 TIMES A WEEK" 4 "3 - 4 TIMES A WEEK"
                       5 "5 - 6 TIMES A WEEK, DAILY OR ALMOST EVER"
                       6 "2 OR MORE TIMES A DAY" ;
label define FD3H      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FD4H      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "WITHIN THE PAST 3 DAYS"
                       2 "WITHIN THE PAST WEEK BUT NOT WITHIN THE"
                       3 "MORE THAN 1 WEEK AGO BUT WITHIN THE PAST"
                       4 "1 - 6 MONTHS AGO" 5 "MORE THAN 6 MONTHS AGO" ;
label define FD1I      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD2I      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "LESS THAN ONCE A MONTH" 2 "1 - 3 TIMES A MONTH"
                       3 "1 - 2 TIMES A WEEK" 4 "3 - 4 TIMES A WEEK"
                       5 "5 - 6 TIMES A WEEK, DAILY OR ALMOST EVER"
                       6 "2 OR MORE TIMES A DAY" ;
label define FD3I      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FD4I      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "WITHIN THE PAST 3 DAYS"
                       2 "WITHIN THE PAST WEEK BUT NOT WITHIN THE"
                       3 "MORE THAN 1 WEEK AGO BUT WITHIN THE PAST"
                       4 "1 - 6 MONTHS AGO" 5 "MORE THAN 6 MONTHS AGO" ;
label define FD1J      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD2J      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "LESS THAN ONCE A MONTH" 2 "1 - 3 TIMES A MONTH"
                       3 "1 - 2 TIMES A WEEK" 4 "3 - 4 TIMES A WEEK"
                       5 "5 - 6 TIMES A WEEK, DAILY OR ALMOST EVER"
                       6 "2 OR MORE TIMES A DAY" ;
label define FD3J      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FD4J      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "WITHIN THE PAST 3 DAYS"
                       2 "WITHIN THE PAST WEEK BUT NOT WITHIN THE"
                       3 "MORE THAN 1 WEEK AGO BUT WITHIN THE PAST"
                       4 "1 - 6 MONTHS AGO" 5 "MORE THAN 6 MONTHS AGO" ;
label define FD1K      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD2K      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "LESS THAN ONCE A MONTH" 2 "1 - 3 TIMES A MONTH"
                       3 "1 - 2 TIMES A WEEK" 4 "3 - 4 TIMES A WEEK"
                       5 "5 - 6 TIMES A WEEK, DAILY OR ALMOST EVER"
                       6 "2 OR MORE TIMES A DAY" ;
label define FD3K      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FD4K      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "WITHIN THE PAST 3 DAYS"
                       2 "WITHIN THE PAST WEEK BUT NOT WITHIN THE"
                       3 "MORE THAN 1 WEEK AGO BUT WITHIN THE PAST"
                       4 "1 - 6 MONTHS AGO" 5 "MORE THAN 6 MONTHS AGO" ;
label define FD1L      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD2L      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "LESS THAN ONCE A MONTH" 2 "1 - 3 TIMES A MONTH"
                       3 "1 - 2 TIMES A WEEK" 4 "3 - 4 TIMES A WEEK"
                       5 "5 - 6 TIMES A WEEK, DAILY OR ALMOST EVER"
                       6 "2 OR MORE TIMES A DAY" ;
label define FD3L      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FD4L      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "WITHIN THE PAST 3 DAYS"
                       2 "WITHIN THE PAST WEEK BUT NOT WITHIN THE"
                       3 "MORE THAN 1 WEEK AGO BUT WITHIN THE PAST"
                       4 "1 - 6 MONTHS AGO" 5 "MORE THAN 6 MONTHS AGO" ;
label define FD1M      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD1MOTH1  -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "ZOLOFT"
                       2 "INSULIN" 3 "TRAZHORNE" 4 "PRESCRIPTION MEDICATION"
                       5 "GH BRAND MUSHROOM" 6 "DEPOKE" 7 "COLONADINE"
                       8 "BLOOD PRESSURE MEDICINE" ;
label define FD2MOTH1  -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "LESS THAN ONCE A MONTH" 2 "1 - 3 TIMES A MONTH"
                       3 "1 - 2 TIMES A WEEK" 4 "3 - 4 TIMES A WEEK"
                       5 "5 - 6 TIMES A WEEK, DAILY OR ALMOST EVER"
                       6 "2 OR MORE TIMES A DAY" ;
label define FD3MOTH1  -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FD4MOTH1  -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "WITHIN THE PAST 3 DAYS"
                       2 "WITHIN THE PAST WEEK BUT NOT WITHIN THE"
                       3 "MORE THAN 1 WEEK AGO BUT WITHIN THE PAST"
                       4 "1 - 6 MONTHS AGO" 5 "MORE THAN 6 MONTHS AGO" ;
label define FD1MOTH2  -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "ZOLOFT"
                       6 "DEPOKE" 7 "TRAZODE" 8 "BLOOD PRESSURE MEDICINE"
                       9 "COLONADINE" 12 "CLODINE" 14 "GH BRAND MUSHROOM"
                       15 "PRESCRIPTION MEDICATION" 17 "TRAZHORNE"
                       18 "INSULIN" 19 "MUSHROOMS" ;
label define FD2MOTH2  -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "LESS THAN ONCE A MONTH" 2 "1 - 3 TIMES A MONTH"
                       3 "1 - 2 TIMES A WEEK" 4 "3 - 4 TIMES A WEEK"
                       5 "5 - 6 TIMES A WEEK, DAILY OR ALMOST EVER"
                       6 "2 OR MORE TIMES A DAY" ;
label define FD3MOTH2  -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FD4MOTH2  -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "WITHIN THE PAST 3 DAYS"
                       2 "WITHIN THE PAST WEEK BUT NOT WITHIN THE"
                       3 "MORE THAN 1 WEEK AGO BUT WITHIN THE PAST"
                       4 "1 - 6 MONTHS AGO" 5 "MORE THAN 6 MONTHS AGO" ;
label define FD1MOTH3  -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "ZOLOFT"
                       6 "DEPOKE" 7 "TRAZODE" 8 "BLOOD PRESSURE MEDICINE"
                       9 "COLONADINE" 12 "CLODINE" 14 "GH BRAND MUSHROOM"
                       15 "PRESCRIPTION MEDICATION" 17 "TRAZHORNE"
                       18 "INSULIN" 19 "MUSHROOMS" ;
label define FD2MOTH3  -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "LESS THAN ONCE A MONTH" 2 "1 - 3 TIMES A MONTH"
                       3 "1 - 2 TIMES A WEEK" 4 "3 - 4 TIMES A WEEK"
                       5 "5 - 6 TIMES A WEEK, DAILY OR ALMOST EVER"
                       6 "2 OR MORE TIMES A DAY" ;
label define FD3MOTH3  -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FD4MOTH3  -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "WITHIN THE PAST 3 DAYS"
                       2 "WITHIN THE PAST WEEK BUT NOT WITHIN THE"
                       3 "MORE THAN 1 WEEK AGO BUT WITHIN THE PAST"
                       4 "1 - 6 MONTHS AGO" 5 "MORE THAN 6 MONTHS AGO" ;
label define FD5       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FD6       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FD7       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "NEVER"
                       2 "LESS THAN ONCE A MONTH" 3 "1 - 3 TIMES A MONTH"
                       4 "1 - 2 TIMES A WEEK" 5 "3 - 4 TIMES A WEEK"
                       6 "DAILY OR ALMOST DAILY" ;
label define FD8       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "NEVER"
                       2 "LESS THAN ONCE A MONTH" 3 "1 - 3 TIMES A MONTH"
                       4 "1 - 2 TIMES A WEEK" 5 "3 - 4 TIMES A WEEK"
                       6 "DAILY OR ALMOST DAILY" ;
label define FD9       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD10      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD11      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "ONE DAY"
                       2 "2 - 5 DAYS" 3 "6 - 10 DAYS" 4 "11 - 20 DAYS"
                       5 "21 DAYS OR MORE" ;
label define FD12A     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD13A     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FD12B     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD13B     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FD12C     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD13C     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FD14      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD15      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD16      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "MARRIED"
                       2 "LIVING WITH SOMEONE AS MARRIED" 3 "SEPARATED"
                       4 "DIVORCED" 5 "WIDOWED" 6 "NEVER MARRIED" ;
label define FD17      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 0 "NONE" ;
label define FD18      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD19      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD20      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD21      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "LESS THAN 1 MONTH" 2 "1 - 6 MONTHS"
                       3 "7 - 11 MONTHS" 4 "12 MONTHS OR MORE" ;
label define FD23A     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD23B     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD23C     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD23D     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD23E     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD23F     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD23G     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD24      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD25      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD26      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FD27      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "CLERICAL WORKER" 2 "SALES WORKER"
                       3 "SERVICE WORKER" 4 "PRIVATE HH WORKER"
                       5 "SKILLED WORKER OR CRAFTSMEN" 6 "LABORER"
                       7 "OPERATOR OR MACHINE OPERATOR"
                       8 "TRANSPORTATION EQUIPMENT OPERATOR" 9 "FARM LABORER"
                       10 "FARMER OR FARM MANAGER" 11 "MANAGER/ADMINISTRATOR"
                       12 "LAY COUNSELOR, PEER COUNSELOR"
                       13 "PROFESSIONAL/TECHNICAL" 96 "OTHER, UNABLE TO CODE" ;
label define FD28A     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "PER HOUR"
                       2 "EVERY WEEK" 3 "EVERY TWO WEEKS" 4 "PER MONTH"
                       5 "PER YEAR" 6 "OTHER (SPECIFY)" ;
label define FD28AOTH  -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 2 "PER JOB"
                       3 "ROOM" 4 "A DAY" 5 "PER CAR" 6 "PER 12 HOUR SHIFT"
                       7 "10 MONTHS" 8 "DEPENDING ON CATCH" ;
label define FD29      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD30      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FD31A     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "PER HOUR"
                       2 "EVERY WEEK" 3 "EVERY TWO WEEKS" 4 "PER MONTH"
                       5 "PER YEAR" 6 "OTHER (SPECIFY)" ;
label define FD31AOTH  -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "PER JOB"
                       2 "DAY" 3 "VOLUNTEER" 4 "WHILE IN TREATMENT"
                       5 "FLAT FEE" 6 "5 MONTHS" 7 "NO INCOME" 8 "COMMISSION"
                       9 "SUPPORT VARIED" 10 "PER CAR" ;
label define FD32A     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD32B     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD32C     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD32D     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD32E     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD32F     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD32G     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD32H     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD32I     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD32J     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD32K     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD32L     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD33A     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD33B     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD33C     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD33D     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD33E     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD33F     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD34A     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD34B     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD34C     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD34D     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD34E     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD35      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD37A     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       0 "THIS TREATMENT NOT USED HOSPITAL OVERNIG" ;
label define FD38A     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FD37B     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       0 "THIS TREATMENT NOT USED RESIDENTIAL PROG" ;
label define FD38B     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FD37C     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       0 "THIS TREATMENT NOT USED OUTPATIENT METHA" ;
label define FD38C     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FD37D     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       0 "THIS TREATMENT NOT USED OUTPATIENT NON-M" ;
label define FD38D     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FD37E     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       0 "THIS TREATMENT NOT USED TREATMENT IN DR" ;
label define FD38E     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FD37F     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       0 "THIS TREATMENT NOT USED HALF-WAY HOUSE" ;
label define FD38F     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FD37G     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       0 "THIS TREATMENT NOT USED DUI/DWI PROGRAM" ;
label define FD38G     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FD37H     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       0 "THIS TREATMENT NOT USED PROGRAM IN ANOTH" ;
label define FD38H     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FD39A     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD40A     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FD41A     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "LESS THAN ONCE A MONTH OR INFREQUENTLY"
                       2 "ONCE A MONTH" 3 "TWO TO THREE TIMES A MONTH"
                       4 "ONCE A WEEK" 5 "ONE TO TWO TIMES A WEEK"
                       6 "DAILY OR ALMOST DAILY" ;
label define FD39B     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD40B     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FD41B     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "LESS THAN ONCE A MONTH OR INFREQUENTLY"
                       2 "ONCE A MONTH" 3 "TWO TO THREE TIMES A MONTH"
                       4 "ONCE A WEEK" 5 "ONE TO TWO TIMES A WEEK"
                       6 "DAILY OR ALMOST DAILY" ;
label define FD39C     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD40C     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FD41C     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "LESS THAN ONCE A MONTH OR INFREQUENTLY"
                       2 "ONCE A MONTH" 3 "TWO TO THREE TIMES A MONTH"
                       4 "ONCE A WEEK" 5 "ONE TO TWO TIMES A WEEK"
                       6 "DAILY OR ALMOST DAILY" ;
label define FD39D     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD40D     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FD41D     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "LESS THAN ONCE A MONTH OR INFREQUENTLY"
                       2 "ONCE A MONTH" 3 "TWO TO THREE TIMES A MONTH"
                       4 "ONCE A WEEK" 5 "ONE TO TWO TIMES A WEEK"
                       6 "DAILY OR ALMOST DAILY" ;
label define FD42      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD42A     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD42B     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD42C     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD42D     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD42E     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD42F     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD42G     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD42H     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD42I     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD43      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD44      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD45      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD46      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD47      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "EXCELLENT,"
                       2 "GOOD," 3 "FAIR, OR" 4 "POOR" ;
label define FD48      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD49A     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD49B     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD49C     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD49D     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD49E     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD49F     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD49G     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD49H     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD49I     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD49J     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD49K     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD49L     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD49M     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD50      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD51      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD52      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD53      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD54      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FD55      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FD56      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FD57      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FD58      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FD59      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD60      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "LESS THAN 1/4 PACK A DAY (1-5 CIGARETTES"
                       2 "ABOUT 1/2 PACK A DAY (6-15 CIGARETTES)"
                       3 "ABOUT A PACK A DAY (16-25 CIGARETTES)"
                       4 "ABOUT 1 1/2 PACKS A DAY (26-35 CIGARETTE"
                       5 "ABOUT 2 PACKS A DAY (OVER 35 CIGARETTES)" ;
label define FD61A     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD61B     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD61C     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD62      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD63      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD64      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD65      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD66      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 0 "NONE"
                       1 "ONE" 2 "2 - 10" 3 "11 - 25" 4 "26 - 100"
                       5 "101 - 500" 6 "MORE THAN 500" ;
label define FD67      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD68A     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD69A     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD68B     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD69B     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD68C     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD69C     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD68D     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD69D     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD68E     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD69E     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD68F     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD69F     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD68G     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD69G     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD68H     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD69H     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD68I     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD69I     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD68J     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD69J     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD68K     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD69K     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD68L     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD69L     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD68M     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD69M     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD68N     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD68NOTH  -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "ACCUSED OF STEALING" 2 "PAROLE/PROBATION VIOLATION"
                       3 "GAMBLING" 4 "WEAPON OFFENSE" 5 "CONTEMPT OF COURT"
                       6 "TRESPASSING" 7 "POSSESSION OF DRUG PARAPHERNALIA"
                       8 "DWI/FAILURE TO PAY FINE"
                       9 "OPEN BEER ON THE STREET" 10 "FAILURE TO PAY TICKET"
                       11 "DRIVING WITHOUT LICENSE" 12 "CHILD SUPPORT"
                       13 "BENCH WARRANT" ;
label define FD69N     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD70      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD71      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FD72      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD73      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD74      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FD75      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FD75U     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "DAYS"
                       2 "WEEKS" 3 "MONTHS" ;
label define FD76      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD77      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD78      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD79      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD80      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FD81A     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD82A     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "MEDICAL"
                       2 "NON-MEDICAL" 3 "BOTH MEDICAL AND NON-MEDICAL" ;
label define FD83A     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD81B     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD82B     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "MEDICAL"
                       2 "NON-MEDICAL" 3 "BOTH MEDICAL AND NON-MEDICAL" ;
label define FD83B     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD81C     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD82C     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "MEDICAL"
                       2 "NON-MEDICAL" 3 "BOTH MEDICAL AND NON-MEDICAL" ;
label define FD83C     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD81D     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD82D     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "MEDICAL"
                       2 "NON-MEDICAL" 3 "BOTH MEDICAL AND NON-MEDICAL" ;
label define FD83D     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD81E     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD82E     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "MEDICAL"
                       2 "NON-MEDICAL" 3 "BOTH MEDICAL AND NON-MEDICAL" ;
label define FD83E     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD81F     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD82F     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "MEDICAL"
                       2 "NON-MEDICAL" 3 "BOTH MEDICAL AND NON-MEDICAL" ;
label define FD83F     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD81G     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD82G     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "MEDICAL"
                       2 "NON-MEDICAL" 3 "BOTH MEDICAL AND NON-MEDICAL" ;
label define FD83G     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD81H     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD82H     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "MEDICAL"
                       2 "NON-MEDICAL" 3 "BOTH MEDICAL AND NON-MEDICAL" ;
label define FD83H     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD81I     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD82I     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "MEDICAL"
                       2 "NON-MEDICAL" 3 "BOTH MEDICAL AND NON-MEDICAL" ;
label define FD83I     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD84A     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "VERY SATISFIED" 2 "SOMEWHAT SATISFIED"
                       3 "NOT AT ALL SATISFIED" ;
label define FD84B     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD84C     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD84D     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "YES" 2 "NO" ;
label define FD84E     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "COMMENT" 2 "NO COMMENT" ;
label define FD84F     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "COMMENT" 2 "NO COMMENT" ;
label define FD84G     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "COMMENT" 2 "NO COMMENT" ;
label define FB2CFLG   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 0 "PASSED EDIT CHECK" 1 "FAILED EDIT CHECK" ;
label define FB2FFLG   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 0 "PASSED EDIT CHECK" 1 "FAILED EDIT CHECK" ;
label define FB2KFLG   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 0 "PASSED EDIT CHECK" 1 "FAILED EDIT CHECK" ;
label define FB82AFLG  -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 0 "PASSED EDIT CHECK" 1 "FAILED EDIT CHECK" ;
label define FB82BFLG  -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 0 "PASSED EDIT CHECK" 1 "FAILED EDIT CHECK" ;
label define FB82CFLG  -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 0 "PASSED EDIT CHECK" 1 "FAILED EDIT CHECK" ;
label define FB82DFLG  -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 0 "PASSED EDIT CHECK" 1 "FAILED EDIT CHECK" ;
label define FB82EFLG  -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 0 "PASSED EDIT CHECK" 1 "FAILED EDIT CHECK" ;
label define FB82FFLG  -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 0 "PASSED EDIT CHECK" 1 "FAILED EDIT CHECK" ;
label define FB82GFLG  -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 0 "PASSED EDIT CHECK" 1 "FAILED EDIT CHECK" ;
label define FB82HFLG  -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 0 "PASSED EDIT CHECK" 1 "FAILED EDIT CHECK" ;
label define FB82IFLG  -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 0 "PASSED EDIT CHECK" 1 "FAILED EDIT CHECK" ;
label define FB82JFLG  -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 0 "PASSED EDIT CHECK" 1 "FAILED EDIT CHECK" ;
label define FB82KFLG  -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 0 "PASSED EDIT CHECK" 1 "FAILED EDIT CHECK" ;
label define FB82LFLG  -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 0 "PASSED EDIT CHECK" 1 "FAILED EDIT CHECK" ;
label define FB82MFLG  -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 0 "PASSED EDIT CHECK" 1 "FAILED EDIT CHECK" ;
label define FB82NFLG  -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 0 "PASSED EDIT CHECK" 1 "FAILED EDIT CHECK" ;
label define FB88AFLG  -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 0 "PASSED EDIT CHECK" 1 "FAILED EDIT CHECK" ;
label define FD36FLG   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       0 "PASSED EDIT CHECK" 1 "FAILED EDIT CHECK" ;
label define FD3BFLG   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       0 "PASSED EDIT CHECK" 1 "FAILED EDIT CHECK" ;
label define FD3CFLG   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       0 "PASSED EDIT CHECK" 1 "FAILED EDIT CHECK" ;
label define FD3DFLG   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       0 "PASSED EDIT CHECK" 1 "FAILED EDIT CHECK" ;
label define FD3EFLG   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       0 "PASSED EDIT CHECK" 1 "FAILED EDIT CHECK" ;
label define FD3FFLG   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       0 "PASSED EDIT CHECK" 1 "FAILED EDIT CHECK" ;
label define FD3GFLG   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       0 "PASSED EDIT CHECK" 1 "FAILED EDIT CHECK" ;
label define FD3IFLG   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       0 "PASSED EDIT CHECK" 1 "FAILED EDIT CHECK" ;
label define FD38BFLG  -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       0 "PASSED EDIT CHECK" 1 "FAILED EDIT CHECK" ;
label define FD38CFLG  -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       0 "PASSED EDIT CHECK" 1 "FAILED EDIT CHECK" ;
label define FD38DFLG  -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       0 "PASSED EDIT CHECK" 1 "FAILED EDIT CHECK" ;
label define FD38FFLG  -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       0 "PASSED EDIT CHECK" 1 "FAILED EDIT CHECK" ;
label define FD38GFLG  -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       0 "PASSED EDIT CHECK" 1 "FAILED EDIT CHECK" ;
label define FD38HFLG  -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       0 "PASSED EDIT CHECK" 1 "FAILED EDIT CHECK" ;
label define FD5FLG    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       0 "PASSED EDIT CHECK" 1 "FAILED EDIT CHECK" ;
label define FD26FLG   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       0 "PASSED EDIT CHECK" 1 "FAILED EDIT CHECK" ;
label define FD30FLG   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       0 "PASSED EDIT CHECK" 1 "FAILED EDIT CHECK" ;
label define FD40AFLG  -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       0 "PASSED EDIT CHECK" 1 "FAILED EDIT CHECK" ;
label define FD40BFLG  -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       0 "PASSED EDIT CHECK" 1 "FAILED EDIT CHECK" ;
label define FD40CFLG  -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       0 "PASSED EDIT CHECK" 1 "FAILED EDIT CHECK" ;
label define FD40DFLG  -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       0 "PASSED EDIT CHECK" 1 "FAILED EDIT CHECK" ;
label define FB64MOTH  -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "BACK PROBLEM" 2 "CHEST PROBLEM" 3 "DROPPED BLADDER"
                       4 "SINUS" 5 "ANKYLOSIS SPONDILITUS"
                       6 "LUNG DISEASE, PNEUMONIA, BRONCHITIS"
                       7 "DENTAL, TEETH PROBLEM" 8 "GUN SHOT OR STAB WOUND"
                       9 "MASTITIS BREAST" 10 "BROKEN BONE" 11 "ALCOHOL"
                       12 "APPENDICITIS" 13 "HAY FEVER" 14 "SPLEEN REMOVAL"
                       15 "HERNIA" 16 "ULCER" 17 "RHEUMATIC FEVER"
                       18 "ASTHMA" 19 "PILLS" 20 "STROKE" 21 "PANCREATITIS"
                       22 "WEIGHT LOSS" 23 "GOUT" 24 "ENDOMETRIOSIS"
                       25 "AIDS" 26 "HIV" 27 "DEPRESSION" 28 "ABSCESSES"
                       29 "MALNUTRITION" 30 "BLADDER CANCER"
                       31 "SLEEP PROBLEM" 32 "WITHDRAWAL"
                       33 "DEFECTIVE HEARING" 34 "CIRCULATION PROBLEMS"
                       35 "MYEANTIUS GRAVIS" 36 "HEMORRHAGING" 37 "PSORIASIS"
                       38 "ALLERGIES" 39 "LOW PLATELETS" 40 "DIABETES"
                       41 "HIGH CHOLESTEROL" 42 "LOST RIGHT EYE"
                       43 "KNEE PROBLEM" 44 "MONONUCLEOSIS"
                       45 "SURGERY FOR OVARIAN CYST"
                       46 "NEUROLOGICAL CONDITIONS" 47 "BONE DISEASE"
                       48 "PYLONYTAL CYTOLOGY" 49 "ARTHRITIS"
                       50 "BROKEN NECK" 51 "THYROID" 52 "HEAD INJURIES"
                       53 "SPINAL PROBLEMS" 54 "HAND INJURY"
                       55 "OSTEOGENETIC SCOLIOSIS" 56 "HIP REPLACEMENT"
                       57 "ANXIETY ATTACK"
                       58 "ENDOCARDICIES/CONTAMINATED BLOOD" 59 "HIP PROBLEM"
                       60 "U.C" 61 "LOW BLOOD PRESSURE" 62 "LEG PROBLEM"
                       63 "JOINT PROBLEM" 64 "VISION" 65 "SHOULDER PROBLEM"
                       66 "REFLEX SYMP DYSTROPHY SYNDROME"
                       67 "HEART PROBLEMS" 68 "LEUKEMIA" 69 "SCHIZOPHRENIA"
                       70 "CAR ACCIDENT" 71 "BRAIN DAMAGE" 72 "TENDINITIS"
                       73 "PINS IN ANKLE" 74 "FOOT PROBLEMS" 75 "DIARRHEA"
                       76 "ULCER" 77 "STOMACH PROBLEMS" 78 "MS"
                       79 "TEMPERO MANDIBULAR JOINT DYSF"
                       80 "LOSS OF BALANCE AND CELLULITIS" 81 "PARALYSIS"
                       82 "BONE DEFORMITY" 83 "GALL BLADDER"
                       84 "CHRONIC FATIGUE SYNDROME" 85 "MUSCLE SPASM"
                       86 "BOILS AND CYSTS" 87 "SEIZURES" 88 "CPD"
                       89 "DETERIORATING BONE, MUSCLE MASS" 90 "BURN SCARS"
                       91 "BLOOD CLOTS" 92 "VIRAL MENINGITIS"
                       93 "CARPAL TUNNEL SYNDROME" 94 "BURSITIS"
                       95 "HYPOGLYCEMIA" 96 "INTESTINAL INFECTION"
                       97 "LOBOTOMY" 98 "MALARIA" 99 "GRAVES DISEASE"
                       100 "MYOFACIA STRAIN" 101 "FIBROMYALGIA"
                       102 "PROSTATE" 103 "OSTEOPOROSIS" 104 "ILIOSTOMY"
                       105 "RECTAL ABCESS" 106 "RECONSTRUCTIVE LEG SURGERY"
                       107 "EYE SURGERY" 108 "PAIN & NUMBNESS IN LIMBS"
                       109 "SWOLLEN LEGS" 110 "CELLULITIS"
                       111 "NERVES, CARDOSIS" 112 "TRAUMA"
                       113 "TORN KNEE CARTILAGE" 114 "LOW BLOOD SUGAR" ;
label define FC7FOTH1  -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "VALIUM/DIAZEPAM" 2 "VICODIN/LORCET/LORTAB"
                       3 "DILANTIN/PHENYTOIN" 4 "PHENOBARBITAL/DONNATAL"
                       5 "XANAX/ALPRAZOLAM" 6 "DESYREL/TRAZODONE" 7 "PROZAC"
                       8 "ALTRAM" 9 "PHENIGREN" 10 "EMPHYSEMA RX"
                       11 "DIABETES RX" 12 "BLOOD PRESSURE MEDICATION"
                       13 "ANTIBIOTICS" 14 "HORMONES" 15 "PREDNISONE"
                       16 "SINEMET" 17 "LASIX" 18 "CARBO-LEVO" 19 "CYLERT"
                       20 "BIRTH CONTROL PILLS" 21 "MOTRIN/IBUPROFEN"
                       22 "ZANTAC" 23 "TAGAMET" 24 "PRINZIDE" 25 "EFFEXOR"
                       26 "BUSPAR" 27 "ZOLOFT/SERTRALINE" 28 "DILAUDID"
                       29 "FAXER FOR DEPRESSION" 30 "MARINOL" 31 "AZT"
                       32 "LITHIUM" 33 "PREMARIN" 34 "ANTIDEPRESSANT"
                       35 "DEMEROL" 36 "BUPRENEX" 37 "TYLENOL" 38 "CODEINE"
                       39 "DECONGESTANT" 40 "DEPAKOTE"
                       41 "CLONAPIN/KLONAPIN/CLONAZEPAM" 42 "ABIAN"
                       43 "MYOSCYAMINE SULFUR" 44 "BRILOSEC" 45 "ZYPREXA"
                       46 "CRIXOVAIN" 47 "BACTRIM/SULFA" 48 "EPIVIR"
                       49 "EPILEPSY MEDICINE" 50 "REOLUIM" 51 "ANCIAD"
                       52 "PROCARDIA" 53 "AMITRIPOLENE" 54 "KEFLEX"
                       55 "ORAVILA" 56 "CLERVIER" 57 "GLYNASE" 58 "SEG"
                       59 "DDI" 60 "VARONINE" 61 "DI" 62 "VIADIN"
                       63 "PAINKILLER" 64 "MEXITIL" 65 "LOWMADIN"
                       66 "CLONIPINE" 67 "TEGRETOL"
                       68 "FIORINAL WITH CODEINE" 69 "RESPIRAL"
                       70 "CHLORAL HYDRATE" 71 "PAXIL" 72 "NEURONTIN"
                       73 "BENTYL" 74 "VITAMINS" 75 "PROLIXIN"
                       76 "HIRISPALDAR" 77 "INSULIN" 78 "SANUTEX"
                       79 "COLOPINE" 80 "OLANZITINE" 81 "CLONIDINE/CATEPRES"
                       82 "ASTHMA RX" 83 "VOLTAREN" 84 "WELLBUTRIN"
                       85 "SYNTHROID" 86 "HEART MEDS" 87 "NAPROXEN"
                       88 "ANTI-INFLAMMATORY" 89 "PAKIPAM" 90 "VASOTEC"
                       91 "MORPHINE" 92 "NORMODYNE" 93 "ASPIRIN"
                       94 "PERCOSET/PERCODAN/OXYCODONE" 95 "DUPROKOTE"
                       96 "COMBVIR/CINBVUR" 97 "BENADRYL" 98 "CLONOMINE"
                       99 "PRILOSEC" 100 "AMATROX" 101 "ZOMIG" 102 "KAIZAC"
                       103 "ASACOL" 104 "QUANADINE" 105 "INJECTIONS"
                       106 "LOZOL" 107 "CELEXA" 108 "GLYBURIDE" 109 "P.K"
                       110 "CALIZEN" 111 "DIET PILLS" 112 "CIMITRIL"
                       113 "LOXITANE" 114 "IMITREX" 115 "AMBIEN" 116 "CECORE"
                       117 "PROVACET" 118 "DEZERMINE" 119 "PHERIBAITAR"
                       120 "INDERAL" 121 "CLOZARIL" 122 "PROXICAPS"
                       123 "SUDAFED" 124 "TYLENOL WITH CODEINE"
                       125 "CARDIZEM" 126 "TERAZOSIN" 127 "LUVOX"
                       128 "ALLERGY MEDICINE" 129 "AZMACORT" 130 "ROBAXIN"
                       131 "COMPAZINE" 132 "TRIXOVAN"
                       133 "PAMELOR/NORTRIPTYLENE" 134 "HYDROCHROLOGYZINE"
                       135 "ANTI ANXIETY" 136 "PEPCID" 137 "TRIAVIL/TRILAFON"
                       138 "NORVIR" 139 "BIOTIN"
                       140 "MEDICINE FOR CHOLESTEROL" 141 "CLOVIDINC"
                       142 "T.B. DRUG" 143 "ZOVIRAX" 144 "ZESTRIL"
                       145 "MUSCLE RELAXER" 146 "KALADINE"
                       147 "TRIAMTERENE/DYAZIDE" 148 "BIOVAL" 149 "DONNATAL"
                       150 "OXAZEPAM/SERAX"
                       151 "VENTOLIN/PROVENTIL/ALBUTEROL" 152 "NITROGLYCERIN"
                       153 "KAOLIN" 154 "FOLIC ACID" 155 "CALIZAN"
                       156 "ZYPREXA" 157 "AFRAVIL" 158 "ZAIRES"
                       159 "COMPAVERE" 160 "VIRAMUNE" 161 "RECRITOR"
                       162 "FOR REFLUX" 163 "DELACTOSE" 164 "BECLOVENT"
                       165 "VAIRESES" 166 "HYDROCLONO" 167 "PRESORIBE"
                       168 "CRAVE" 169 "SEDATIVES" 170 "3TC" 171 "REPISAL"
                       172 "HYADOL" 173 "CALDURA" 174 "ADALAT" 175 "HCTZ"
                       176 "MONOPIN" 177 "CIPRO" 178 "CALAN" 179 "CARDENSA"
                       180 "AMOXYCILLIN" 181 "COUGH SYRUP"
                       182 "FOR ARTHRITIS" 183 "VIRACEPT" 184 "SELDANE"
                       185 "FOR CONSTIPATION" 186 "ANADROL" 187 "ZERIT"
                       188 "NAPROSYN" 189 "ADDERAL" 190 "HYDROXYZINE"
                       191 "THIAMINE" 192 "PIMX" 193 "NORVASC"
                       194 "THEOPHYLLINE" 195 "DARVON/DARVOCET"
                       196 "FUBERCIOUS" 197 "SALSALATE" 198 "MELLARIL"
                       199 "QUADINE" 200 "SERZONE" 201 "RISPERDAL"
                       202 "HYDROCORDINE" 203 "NORTHRIPINE"
                       204 "CARISOPRODOL/SOMA" 205 "SLEEPING PILLS"
                       206 "TRANQUILIZERS" 207 "POTASSIUM" 208 "RITALIN"
                       209 "VISTARIL" 210 "HALCYON" 211 "FEN-PHEN"
                       212 "INDOVRAL" 213 "HIV MEDICINE" 214 "ETOH"
                       215 "COLCHICINE" 216 "MALEATE POLARAMINE"
                       217 "SOMETHING TO RELAX"
                       218 "BLOOD THINNER OR PEMETHIAN"
                       219 "MEDICATION TO CURB URGE TO DRINK"
                       220 "ATIVAN/LORAZEPAM" 221 "GLAVIDA" 222 "BENZTROPINE"
                       223 "SIMVASTATIN/ZOCOR" 224 "FLUPHENAZINE"
                       225 "DALMANE" 226 "CLINADAPAN" 227 "RISEROL"
                       228 "DOXEPIN/SINEQUAN" 229 "PENICILLIN" 230 "LIBRIUM"
                       231 "KEMADRIN" 232 "THORAZINE" ;
label define FC7FOTH2  -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "VALIUM/DIAZEPAM" 2 "VICODIN/LORCET/LORTAB"
                       3 "DILANTIN/PHENYTOIN" 4 "PHENOBARBITAL/DONNATAL"
                       5 "XANAX/ALPRAZOLAM" 6 "DESYREL/TRAZODONE" 7 "PROZAC"
                       8 "ALTRAM" 9 "PHENIGREN" 10 "EMPHYSEMA RX"
                       11 "DIABETES RX" 12 "BLOOD PRESSURE MEDICATION"
                       13 "ANTIBIOTICS" 14 "HORMONES" 15 "PREDNISONE"
                       16 "SINEMET" 17 "LASIX" 18 "CARBO-LEVO" 19 "CYLERT"
                       20 "BIRTH CONTROL PILLS" 21 "MOTRIN/IBUPROFEN"
                       22 "ZANTAC" 23 "TAGAMET" 24 "PRINZIDE" 25 "EFFEXOR"
                       26 "BUSPAR" 27 "ZOLOFT/SERTRALINE" 28 "DILAUDID"
                       29 "FAXER FOR DEPRESSION" 30 "MARINOL" 31 "AZT"
                       32 "LITHIUM" 33 "PREMARIN" 34 "ANTIDEPRESSANT"
                       35 "DEMEROL" 36 "BUPRENEX" 37 "TYLENOL" 38 "CODEINE"
                       39 "DECONGESTANT" 40 "DEPAKOTE"
                       41 "CLONAPIN/KLONAPIN/CLONAZEPAM" 42 "ABIAN"
                       43 "MYOSCYAMINE SULFUR" 44 "BRILOSEC" 45 "ZYPREXA"
                       46 "CRIXOVAIN" 47 "BACTRIM/SULFA" 48 "EPIVIR"
                       49 "EPILEPSY MEDICINE" 50 "REOLUIM" 51 "ANCIAD"
                       52 "PROCARDIA" 53 "AMITRIPOLENE" 54 "KEFLEX"
                       55 "ORAVILA" 56 "CLERVIER" 57 "GLYNASE" 58 "SEG"
                       59 "DDI" 60 "VARONINE" 61 "DI" 62 "VIADIN"
                       63 "PAINKILLER" 64 "MEXITIL" 65 "LOWMADIN"
                       66 "CLONIPINE" 67 "TEGRETOL"
                       68 "FIORINAL WITH CODEINE" 69 "RESPIRAL"
                       70 "CHLORAL HYDRATE" 71 "PAXIL" 72 "NEURONTIN"
                       73 "BENTYL" 74 "VITAMINS" 75 "PROLIXIN"
                       76 "HIRISPALDAR" 77 "INSULIN" 78 "SANUTEX"
                       79 "COLOPINE" 80 "OLANZITINE" 81 "CLONIDINE/CATEPRES"
                       82 "ASTHMA RX" 83 "VOLTAREN" 84 "WELLBUTRIN"
                       85 "SYNTHROID" 86 "HEART MEDS" 87 "NAPROXEN"
                       88 "ANTI-INFLAMMATORY" 89 "PAKIPAM" 90 "VASOTEC"
                       91 "MORPHINE" 92 "NORMODYNE" 93 "ASPIRIN"
                       94 "PERCOSET/PERCODAN/OXYCODONE" 95 "DUPROKOTE"
                       96 "COMBVIR/CINBVUR" 97 "BENADRYL" 98 "CLONOMINE"
                       99 "PRILOSEC" 100 "AMATROX" 101 "ZOMIG" 102 "KAIZAC"
                       103 "ASACOL" 104 "QUANADINE" 105 "INJECTIONS"
                       106 "LOZOL" 107 "CELEXA" 108 "GLYBURIDE" 109 "P.K"
                       110 "CALIZEN" 111 "DIET PILLS" 112 "CIMITRIL"
                       113 "LOXITANE" 114 "IMITREX" 115 "AMBIEN" 116 "CECORE"
                       117 "PROVACET" 118 "DEZERMINE" 119 "PHERIBAITAR"
                       120 "INDERAL" 121 "CLOZARIL" 122 "PROXICAPS"
                       123 "SUDAFED" 124 "TYLENOL WITH CODEINE"
                       125 "CARDIZEM" 126 "TERAZOSIN" 127 "LUVOX"
                       128 "ALLERGY MEDICINE" 129 "AZMACORT" 130 "ROBAXIN"
                       131 "COMPAZINE" 132 "TRIXOVAN"
                       133 "PAMELOR/NORTRIPTYLENE" 134 "HYDROCHROLOGYZINE"
                       135 "ANTI ANXIETY" 136 "PEPCID" 137 "TRIAVIL/TRILAFON"
                       138 "NORVIR" 139 "BIOTIN"
                       140 "MEDICINE FOR CHOLESTEROL" 141 "CLOVIDINC"
                       142 "T.B. DRUG" 143 "ZOVIRAX" 144 "ZESTRIL"
                       145 "MUSCLE RELAXER" 146 "KALADINE"
                       147 "TRIAMTERENE/DYAZIDE" 148 "BIOVAL" 149 "DONNATAL"
                       150 "OXAZEPAM/SERAX"
                       151 "VENTOLIN/PROVENTIL/ALBUTEROL" 152 "NITROGLYCERIN"
                       153 "KAOLIN" 154 "FOLIC ACID" 155 "CALIZAN"
                       156 "ZYPREXA" 157 "AFRAVIL" 158 "ZAIRES"
                       159 "COMPAVERE" 160 "VIRAMUNE" 161 "RECRITOR"
                       162 "FOR REFLUX" 163 "DELACTOSE" 164 "BECLOVENT"
                       165 "VAIRESES" 166 "HYDROCLONO" 167 "PRESORIBE"
                       168 "CRAVE" 169 "SEDATIVES" 170 "3TC" 171 "REPISAL"
                       172 "HYADOL" 173 "CALDURA" 174 "ADALAT" 175 "HCTZ"
                       176 "MONOPIN" 177 "CIPRO" 178 "CALAN" 179 "CARDENSA"
                       180 "AMOXYCILLIN" 181 "COUGH SYRUP"
                       182 "FOR ARTHRITIS" 183 "VIRACEPT" 184 "SELDANE"
                       185 "FOR CONSTIPATION" 186 "ANADROL" 187 "ZERIT"
                       188 "NAPROSYN" 189 "ADDERAL" 190 "HYDROXYZINE"
                       191 "THIAMINE" 192 "PIMX" 193 "NORVASC"
                       194 "THEOPHYLLINE" 195 "DARVON/DARVOCET"
                       196 "FUBERCIOUS" 197 "SALSALATE" 198 "MELLARIL"
                       199 "QUADINE" 200 "SERZONE" 201 "RISPERDAL"
                       202 "HYDROCORDINE" 203 "NORTHRIPINE"
                       204 "CARISOPRODOL/SOMA" 205 "SLEEPING PILLS"
                       206 "TRANQUILIZERS" 207 "POTASSIUM" 208 "RITALIN"
                       209 "VISTARIL" 210 "HALCYON" 211 "FEN-PHEN"
                       212 "INDOVRAL" 213 "HIV MEDICINE" 214 "ETOH"
                       215 "COLCHICINE" 216 "MALEATE POLARAMINE"
                       217 "SOMETHING TO RELAX"
                       218 "BLOOD THINNER OR PEMETHIAN"
                       219 "MEDICATION TO CURB URGE TO DRINK"
                       220 "ATIVAN/LORAZEPAM" 221 "GLAVIDA" 222 "BENZTROPINE"
                       223 "SIMVASTATIN/ZOCOR" 224 "FLUPHENAZINE"
                       225 "DALMANE" 226 "CLINADAPAN" 227 "RISEROL"
                       228 "DOXEPIN/SINEQUAN" 229 "PENICILLIN" 230 "LIBRIUM"
                       231 "KEMADRIN" 232 "THORAZINE" ;
label define FC7FOTH3  -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "VALIUM/DIAZEPAM" 2 "VICODIN/LORCET/LORTAB"
                       3 "DILANTIN/PHENYTOIN" 4 "PHENOBARBITAL/DONNATAL"
                       5 "XANAX/ALPRAZOLAM" 6 "DESYREL/TRAZODONE" 7 "PROZAC"
                       8 "ALTRAM" 9 "PHENIGREN" 10 "EMPHYSEMA RX"
                       11 "DIABETES RX" 12 "BLOOD PRESSURE MEDICATION"
                       13 "ANTIBIOTICS" 14 "HORMONES" 15 "PREDNISONE"
                       16 "SINEMET" 17 "LASIX" 18 "CARBO-LEVO" 19 "CYLERT"
                       20 "BIRTH CONTROL PILLS" 21 "MOTRIN/IBUPROFEN"
                       22 "ZANTAC" 23 "TAGAMET" 24 "PRINZIDE" 25 "EFFEXOR"
                       26 "BUSPAR" 27 "ZOLOFT/SERTRALINE" 28 "DILAUDID"
                       29 "FAXER FOR DEPRESSION" 30 "MARINOL" 31 "AZT"
                       32 "LITHIUM" 33 "PREMARIN" 34 "ANTIDEPRESSANT"
                       35 "DEMEROL" 36 "BUPRENEX" 37 "TYLENOL" 38 "CODEINE"
                       39 "DECONGESTANT" 40 "DEPAKOTE"
                       41 "CLONAPIN/KLONAPIN/CLONAZEPAM" 42 "ABIAN"
                       43 "MYOSCYAMINE SULFUR" 44 "BRILOSEC" 45 "ZYPREXA"
                       46 "CRIXOVAIN" 47 "BACTRIM/SULFA" 48 "EPIVIR"
                       49 "EPILEPSY MEDICINE" 50 "REOLUIM" 51 "ANCIAD"
                       52 "PROCARDIA" 53 "AMITRIPOLENE" 54 "KEFLEX"
                       55 "ORAVILA" 56 "CLERVIER" 57 "GLYNASE" 58 "SEG"
                       59 "DDI" 60 "VARONINE" 61 "DI" 62 "VIADIN"
                       63 "PAINKILLER" 64 "MEXITIL" 65 "LOWMADIN"
                       66 "CLONIPINE" 67 "TEGRETOL"
                       68 "FIORINAL WITH CODEINE" 69 "RESPIRAL"
                       70 "CHLORAL HYDRATE" 71 "PAXIL" 72 "NEURONTIN"
                       73 "BENTYL" 74 "VITAMINS" 75 "PROLIXIN"
                       76 "HIRISPALDAR" 77 "INSULIN" 78 "SANUTEX"
                       79 "COLOPINE" 80 "OLANZITINE" 81 "CLONIDINE/CATEPRES"
                       82 "ASTHMA RX" 83 "VOLTAREN" 84 "WELLBUTRIN"
                       85 "SYNTHROID" 86 "HEART MEDS" 87 "NAPROXEN"
                       88 "ANTI-INFLAMMATORY" 89 "PAKIPAM" 90 "VASOTEC"
                       91 "MORPHINE" 92 "NORMODYNE" 93 "ASPIRIN"
                       94 "PERCOSET/PERCODAN/OXYCODONE" 95 "DUPROKOTE"
                       96 "COMBVIR/CINBVUR" 97 "BENADRYL" 98 "CLONOMINE"
                       99 "PRILOSEC" 100 "AMATROX" 101 "ZOMIG" 102 "KAIZAC"
                       103 "ASACOL" 104 "QUANADINE" 105 "INJECTIONS"
                       106 "LOZOL" 107 "CELEXA" 108 "GLYBURIDE" 109 "P.K"
                       110 "CALIZEN" 111 "DIET PILLS" 112 "CIMITRIL"
                       113 "LOXITANE" 114 "IMITREX" 115 "AMBIEN" 116 "CECORE"
                       117 "PROVACET" 118 "DEZERMINE" 119 "PHERIBAITAR"
                       120 "INDERAL" 121 "CLOZARIL" 122 "PROXICAPS"
                       123 "SUDAFED" 124 "TYLENOL WITH CODEINE"
                       125 "CARDIZEM" 126 "TERAZOSIN" 127 "LUVOX"
                       128 "ALLERGY MEDICINE" 129 "AZMACORT" 130 "ROBAXIN"
                       131 "COMPAZINE" 132 "TRIXOVAN"
                       133 "PAMELOR/NORTRIPTYLENE" 134 "HYDROCHROLOGYZINE"
                       135 "ANTI ANXIETY" 136 "PEPCID" 137 "TRIAVIL/TRILAFON"
                       138 "NORVIR" 139 "BIOTIN"
                       140 "MEDICINE FOR CHOLESTEROL" 141 "CLOVIDINC"
                       142 "T.B. DRUG" 143 "ZOVIRAX" 144 "ZESTRIL"
                       145 "MUSCLE RELAXER" 146 "KALADINE"
                       147 "TRIAMTERENE/DYAZIDE" 148 "BIOVAL" 149 "DONNATAL"
                       150 "OXAZEPAM/SERAX"
                       151 "VENTOLIN/PROVENTIL/ALBUTEROL" 152 "NITROGLYCERIN"
                       153 "KAOLIN" 154 "FOLIC ACID" 155 "CALIZAN"
                       156 "ZYPREXA" 157 "AFRAVIL" 158 "ZAIRES"
                       159 "COMPAVERE" 160 "VIRAMUNE" 161 "RECRITOR"
                       162 "FOR REFLUX" 163 "DELACTOSE" 164 "BECLOVENT"
                       165 "VAIRESES" 166 "HYDROCLONO" 167 "PRESORIBE"
                       168 "CRAVE" 169 "SEDATIVES" 170 "3TC" 171 "REPISAL"
                       172 "HYADOL" 173 "CALDURA" 174 "ADALAT" 175 "HCTZ"
                       176 "MONOPIN" 177 "CIPRO" 178 "CALAN" 179 "CARDENSA"
                       180 "AMOXYCILLIN" 181 "COUGH SYRUP"
                       182 "FOR ARTHRITIS" 183 "VIRACEPT" 184 "SELDANE"
                       185 "FOR CONSTIPATION" 186 "ANADROL" 187 "ZERIT"
                       188 "NAPROSYN" 189 "ADDERAL" 190 "HYDROXYZINE"
                       191 "THIAMINE" 192 "PIMX" 193 "NORVASC"
                       194 "THEOPHYLLINE" 195 "DARVON/DARVOCET"
                       196 "FUBERCIOUS" 197 "SALSALATE" 198 "MELLARIL"
                       199 "QUADINE" 200 "SERZONE" 201 "RISPERDAL"
                       202 "HYDROCORDINE" 203 "NORTHRIPINE"
                       204 "CARISOPRODOL/SOMA" 205 "SLEEPING PILLS"
                       206 "TRANQUILIZERS" 207 "POTASSIUM" 208 "RITALIN"
                       209 "VISTARIL" 210 "HALCYON" 211 "FEN-PHEN"
                       212 "INDOVRAL" 213 "HIV MEDICINE" 214 "ETOH"
                       215 "COLCHICINE" 216 "MALEATE POLARAMINE"
                       217 "SOMETHING TO RELAX"
                       218 "BLOOD THINNER OR PEMETHIAN"
                       219 "MEDICATION TO CURB URGE TO DRINK"
                       220 "ATIVAN/LORAZEPAM" 221 "GLAVIDA" 222 "BENZTROPINE"
                       223 "SIMVASTATIN/ZOCOR" 224 "FLUPHENAZINE"
                       225 "DALMANE" 226 "CLINADAPAN" 227 "RISEROL"
                       228 "DOXEPIN/SINEQUAN" 229 "PENICILLIN" 230 "LIBRIUM"
                       231 "KEMADRIN" 232 "THORAZINE" ;
label define FD49MOTH  -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "BACK PROBLEMS" 2 "STROKE" 3 "BONES AND JOINTS"
                       4 "ANKYLOSIS SPONDILITIS" 5 "SINUS" 6 "DIABETES"
                       7 "KNEE INJURY" 8 "BROKEN RIBS" 9 "PINCHED NERVE"
                       10 "FEMALE PROBLEMS" 11 "CANT DO ANYTHING FOR MYSELF"
                       12 "RETINITIS PIGMENOTOSA" 13 "EMPHYSEMA" 14 "HERNIA"
                       15 "ULCER" 16 "COLITIS" 17 "ASTHMA" 18 "BURSITIS"
                       19 "LEG AMPUTATED" 20 "DROPPED BLADDER"
                       21 "CAR ACCIDENT" 22 "ENDOMETRIOSIS" 23 "PNEUMONIA"
                       24 "FEET PROBLEMS" 25 "HIV" 26 "MEIGS SYNDROME"
                       27 "ABSCESSES" 28 "PSORIASIS" 29 "ANEURYSM IN STOMACH"
                       30 "BROKEN COLLAR BONE" 31 "ALLERGIES"
                       32 "HIGH CHOLESTEROL" 33 "GOUT" 34 "ARTHRITIS" 35 "DM"
                       36 "INNER EAR PROBLEM" 37 "CHRONIC MUSCLE DAMAGE"
                       38 "YEAST" 39 "THERAPY AFTER ARM SURGERY"
                       40 "BRONCHITIS" 41 "BLADDER INFECTION"
                       42 "NEUROLOGICAL" 43 "OSTEOPOROSIS"
                       44 "ARTHRITIS AND DIABETES" 45 "STOMACH"
                       46 "BROKEN NECK" 47 "SMOKING" 48 "IRRITABLE BOWEL"
                       49 "HIPS" 50 "LEG PROBLEMS"
                       51 "BROKE PELVIS, FRACTURED HAND"
                       52 "PROTIRIA CARFANIA TARDA (PCT)" 53 "INJURY TO ARM"
                       54 "CARPAL TUNNEL SYNDROME" 55 "GALL BLADDER"
                       56 "ANKLE PROBLEMS" 57 "HYPOKEILMIC" 58 "PLEURISY"
                       59 "BROKE FINGER" 60 "CANCER" 61 "WEIGHT CONTROL"
                       62 "CANT WORK" 63 "ANOREXIA" 64 "CELLULITIS" 65 "M.S"
                       66 "POSITIVE LUPUS" 67 "SURGERY-BACK, KNEE & HAND"
                       68 "A VASCULA NECROSIS" 69 "THYROID LEVEL"
                       70 "BRAIN DAMAGE" 71 "SHORTNESS OF BREATH"
                       72 "BRAIN SURGERY" 73 "LUNG DISEASE" 74 "VERTIGO"
                       75 "HIGH RISK PREGNANCY" 76 "LOSS OF MEMORY"
                       77 "CATARACTS" 78 "DIARRHEA" 79 "SIGHT PROBLEMS"
                       80 "SKIN CONDITION" 81 "DTS" 82 "BROKEN ARM"
                       83 "IMMUNE DEFICIENCY" 84 "NAM WOUNDS" 85 "INSOMNIA"
                       86 "JUST SICK" 87 "PANCREAS" 88 "TEETH" 89 "FATIGUE"
                       90 "HYPOGLYCEMIA" 91 "HEAD INJURY" 92 "BONE DEFORMITY"
                       93 "SHOULDER" 94 "ECZEMA" 95 "TENDONITIS"
                       96 "HIGH ENZYMES" 97 "CROHNS DISEASE" 98 "STRESS"
                       99 "PARAPLEGIC" 100 "NECK/EYE NERVE DAMAGE" 101 "PAIN"
                       102 "BRAIN TUMOR" 103 "POLYPS ON THROAT"
                       104 "FIBROMYALGIA" 105 "RASH" 106 "TORN LIGAMENTS"
                       107 "NEUROPATHY-LEGS" 108 "CUT FINGER"
                       109 "WOUNDS FROM FIGHTING" 110 "BONE DISEASE"
                       111 "PELVIC INFECTION" 112 "HAND INJURY" ;
label define FD81IOTH  -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" 1 "CYLERT"
                       2 "DOXYCYCLINE" 3 "PROZAC" 4 "ZOLOFT" 5 "CARDIZEN"
                       6 "PEPCID" 7 "NEURONTIN" 8 "ACID" 9 "KLOPIN"
                       10 "IBUPROFEN" 11 "BENADRYL" 12 "FLEXERIL"
                       13 "DEPAKOTE" 14 "PROPRANOL" 15 "CLARITON" 16 "LUVOX"
                       17 "ANTABUSE" 18 "ROBITUSSIN" 19 "AMBIEN" 20 "WHIPPER"
                       21 "PREVENTIL" 22 "NYQUIL" 23 "REMERON"
                       24 "PRESCRIBED MEDS" 25 "ANACIN"
                       26 "BIPOLAR MEDICATION" 27 "VASOTEC" 28 "PARVAN"
                       29 "TEGRETOL" 30 "DESIPRAMINE" 31 "AMITRYPTYLINE"
                       32 "DESYRIL" 33 "AIDS/HIV DRUG" 34 "PREVICID"
                       35 "BUSPAR" 36 "TYLENOL" 37 "NYTOL" 38 "THERAFLU"
                       39 "FOR HEART DISEASE" 40 "PRILOSEC" 41 "NASACORT"
                       42 "BENADRYL" 43 "COLD MED" 44 "CUMIDIN" 45 "CIMITRIL"
                       46 "EUBRIUM" 47 "VITAMINS" 48 "PROCARDIA" 49 "CULAZAN"
                       50 "SULFADIAZINE" 51 "ASTHMA CORT" 52 "SINUS MED"
                       53 "PREDNISONE" 54 "AZT" 55 "MEDIPRES"
                       56 "PSEUDO PINPHETIDINE" 57 "ZESTRIL"
                       58 "MUSCLE RELAXER" 59 "REZOLIN" 60 "VICAND"
                       61 "ARTHRITIS MEDICATION" 62 "ANTIBIOTIC" 63 "CALAN"
                       64 "PROCARDICE" 65 "RR" 66 "KETOPROFEN"
                       67 "PAIN KILLERS" 68 "HYDROCORTHIZER" 69 "GLYBURIDE"
                       70 "PAIN & BACK PAIN MEDICINE" 71 "LORACAPOM"
                       72 "INSULIN" 73 "WELLBURTIN" 74 "DIALANTIN"
                       75 "GLUCOPHAGE" 76 "PANCOF" 77 "COUGH SUPPRESSANT"
                       78 "GLIPIZIDE" 79 "ERYTHROMYCIN" 80 "ASACOL"
                       81 "KYZAC" 82 "NOPROXEN" 83 "ANTIDEPRESSANTS"
                       84 "FUROSENIDE" 85 "CLONODINE" 86 "PROVACET" 87 "MEDS"
                       88 "ZYBAN" 89 "KLONINE" 90 "ECSTACY" 91 "INTERFERON"
                       92 "EFFECTXOR" 93 "OLANZIPINE" 94 "COLOPINE"
                       95 "LITHIUM" 96 "RISPERDAL" 97 "SLAMM" 98 "PAXIL"
                       99 "CLAUDIPINS" 100 "DIABETES MEDICATION"
                       101 "STEROID" 102 "KEFLEX" 103 "BACTRIM"
                       104 "THYROID MEDICATION" 105 "ALLEUL" 106 "LODINE"
                       107 "ZYPREHA" 108 "DILTIAZEM" 109 "TRAZODONE"
                       110 "SARAGRIL" 111 "HIGH CHOLESTEROL MEDICATION"
                       112 "PHENTERMINE" 113 "CLONAZAPAN" 114 "CLOZERAL"
                       115 "CHOLOPHEN" 116 "ULTRANX"
                       117 "GLOUCONTRO CARDIZAM" 118 "MELLARIL"
                       119 "ATENOLOL" 120 "MOTRIN" 121 "GLUCOPHASE"
                       122 "IODINE" 123 "BLOOD PRESSURE MEDICINE"
                       124 "MAX-ALERT" 125 "LAAM" 126 "ANTI-INFLAMMATORY"
                       127 "ASPIRIN" 128 "MULTIPLE DRUGS LISTED" ;
label define FC23      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "COMPLETED THE TX PLAN OR GRADUATED FROM"
                       2 "DROPPED FROM PROGRAM BY STAFF BECAUSE OF"
                       3 "DROPPED FROM PROGRAM BECAUSE YOUR INSURA"
                       4 "DID NOT WANT TO BE THERE IN THE FIRST PL"
                       5 "FELT THAT THE TREATMENT WAS NOT WORKING"
                       6 "TRANSFERRED TO OTHER PROGRAM BECAUSE YOU"
                       7 "WERE NO LONGER ELIGIBLE" 8 "WENT TO JAIL OR PRISON"
                       9 "TOO DIFFICULT TO GET THERE/CHILD CARE PR"
                       10 "YOU COULDNT AFFORD IT"
                       11 "THERE WAS PRESSURE FROM FAMILY/FRIENDS T"
                       12 "YOU LEFT THE AREA" 13 "TOO SICK"
                       14 "HEALTH RELATED PROBLEMS NOT HANDLED"
                       15 "LABEL TO BE DETERMINED"
                       16 "ARRESTED, NOT IMPRISONED"
                       17 "DISSATISFIED OR WANTED DIFFERENT TREATME"
                       18 "HOSPITALIZED FOR HIGH BLOOD PRESSURE"
                       19 "STOPPED USING, GOT JOB BACK"
                       20 "RELIGIOUS BELIEFS" 21 "PRESSURE FROM DR"
                       22 "HEALTH" 23 "DIDN'T GO/DIDN'T HAVE TIME"
                       24 "REFERRAL"
                       25 "LAWYER GOT HIM OUT OF GOING BACK TO CLAS"
                       26 "WAS TOLD DIDN'T HAVE PROBLEM"
                       27 "COMPLETED COURT REQUIREMENT/COURT ORDERE"
                       28 "TRANSFERRED TO ANOTHER COMPANY" 29 "WENT ONE DAY"
                       30 "TRANSFER TO DIFFERENT PROGRAM (NO REASON"
                       31 "WENT TO COURT, CHARGES DISMISSED"
                       32 "GOT OUT OF IT WHAT I NEED" 33 "JUST OUT OF IT"
                       34 "STILL IN PROGRAM" 35 "NO CLOTHES TO WEAR"
                       36 "TOO MUCH TIME" 37 "PROVIDED GROUP COUNSELING"
                       38 "RELAPSE" 39 "NONE" 40 "STOPPED GOING"
                       41 "WORKED ON HELPING HIMSELF W/WIFES MENTA"
                       42 "WANTED TO EXTEND PROGRAM" 43 "CONTINUED LATER"
                       44 "MOTHER BECAME ILL" 45 "LOST DOCTOR" 46 "NOT SURE"
                       47 "GOT TIRED, STOP USING" 48 "RELEASED FROM JAIL"
                       49 "TOO BUSY" 50 "HELP MYSELF"
                       51 "TAKE CARE OF FATHER" 52 "TO LIBERATE MY LIFE"
                       53 "MEDICAL REASONS" 54 "PAROLE OR PROBATION WAS OVER"
                       55 "TO COME HOME" 56 "DIDN'T GET IN" 57 "DEPRESSED"
                       58 "MISSED CHILDREN"
                       59 "STIPULATED FOR 90 DAYS, SO STOPPED" ;
label define FC29OOTH  -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER"
                       1 "RECOGNIZE PROBLEM" 2 "BE MORE CONSISTENT"
                       3 "DECIDE NOT TO DRINK/DRIVE" 4 "WITH SEXUAL ISSUES"
                       5 "MET SOME GOOD PEOPLE" 6 "OPEN JOURNEYS"
                       7 "ONE COUNSELOR" 8 "LEARN NEW LAWS"
                       9 "CHANCE TO SEE MYSELF" 10 "BALANCED LIFE"
                       11 "DIDN'T GO AT ALL/NEVER WENT"
                       12 "GAIN SELF RESPECT"
                       13 "RECOMMENDED A STAY AT LOCATION" 14 "IM NOT ALONE"
                       15 "OVERALL OUTLOOK/ATTITUDE/ACCEPTANCE/AWAR"
                       16 "GET INTO ANOTHER TREATMENT PROGRAM"
                       17 "OTHER ADDICTION ISSUES"
                       18 "SELF PROCLAIMED DEALER"
                       19 "LEARNING SOMETHING IS ALWAYS GOOD"
                       20 "RECOGNIZING MY FEELINGS" 21 "WITH PERSONAL LIFE"
                       22 "GOOD LECTURES"
                       23 "UNDERSTAND PROBLEM W/SELLING DRUGS"
                       24 "HOW TO LIVE LIFE" 25 "TAUGHT ME TO GROW UP"
                       26 "SPIRITUALITY/RELIGION" 27 "DETOX FROM METH"
                       28 "MADE CLEAN AND SOBER FRIENDS THERE"
                       29 "BETTER FUTURE" 30 "STABILIZING"
                       31 "TO GO TO DETOX" 32 "PLOWED ME DOWN"
                       33 "KEPT ME OUT OF TROUBLE" 34 "KEPT ME FROM DYING"
                       35 "IT HELPS" 36 "NOTHING AT ALL"
                       37 "ADULT CHILD OF ALCOHOLICS" 38 "BE MORE SANE"
                       39 "MORE ACTIVE" 40 "LOSS OF PARENT" 41 "MADE ME SICK"
                       42 "PROVIDING BACK UP" 43 "MANY DIFFERENT WAYS"
                       44 "RESIDENTIAL REHAB"
                       45 "CUT OFF BAD INFLUENCES WITH FRIENDS"
                       46 "EDUCATION/KNOWLEDGE OF ADDICTION"
                       47 "GET IN TOUCH W/ NATIVE AMREICAN ANCESTRY"
                       48 "LEFT BAD RELATIONSHIP" 49 "PROFESSIONAL BALANCE"
                       50 "SKILLS TO SURVIVE" 51 "BETTER RELATIONSHIPS"
                       52 "GET ON SOCIAL SERVICES" 53 "STAY OFF STREETS"
                       54 "SAVED MY LIFE" 55 "SMOKED TOO MUCH MARIJUANA"
                       56 "MORALS SUPPORT" 57 "REFERRED TO MALVERN"
                       58 "DISCIPLINE" 59 "DEALING WITH LIFE"
                       60 "DEAL W/PROBLEMS" 61 "RELAXATION" 62 "RELAPSE"
                       63 "DETOX" 64 "COUNSELOR BEING THERE"
                       65 "UNDERSTAND MOMS PROBLEMS"
                       66 "NOT WORRIED ABOUT GETTING DRUGS"
                       67 "SOMEONE TO TALK TO" 68 "IT WAS ALL GOOD"
                       69 "PREPARE FOR ANOTHER PROGRAM"
                       70 "UNDERSTAND PSYCHOLOGICAL NEEDS"
                       71 "AN EFFORT TO GRADUATE"
                       72 "RECOMMENDATIONS TO OTHER CLINICS" ;
label define FDAYSDCG  -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define F_NEXTTX  -9 "INAPPLICABLE, CLIENTS STILL IN TREATMENT"
                       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       -5 "MISSING" -4 "OTHER" ;
label define F_AGEINT  -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define A73       -9 "INAPPLICABLE IN-TX METH CLIENT STILL IN"
                       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       -5 "MISSING" -4 "OTHER" 0 "CLIENT DECEASED"
                       1 "COMPLETED PLANNED TREATMENT"
                       2 "DID NOT COMPLETE TX REFERRED/TRANSFERRED"
                       3 "DID NOT COMPLETE TX INSURANCE BENEFITS E"
                       4 "DID NOT COMPLETE TX NO PAYMENT SOURCE"
                       5 "DID NOT COMPLETE TX BY ADMINISTRATION CH"
                       6 "DID NOT COMPLETE TX BY CLIENT CHOICE"
                       7 "DID NOT COMPLETE TX INCARCERATED"
                       8 "DID NOT COMPLETE TX NOT OTHERWISE SPECIF"
                       9 "PENDING COMPLETION OF ASSIGNMENT"
                       10 "MUTUAL AGREEMENT TO TERMINATE"
                       11 "LAWYER TERMINATED THERAPY, COURT TERMINA"
                       12 "TREATMENT NEVER STARTED"
                       13 "PROBLEMS WITH TRANSPORTATION" 14 "EVALUATION ONLY"
                       15 "ARRESTED" 16 "MOVED AWAY"
                       17 "DROP OUT, PHYSICAL ILLNESS (E.G., CANCER"
                       18 "REFERRED TO NON-SA TREATMENT"
                       19 "MEDICALLY DISCHARGE AFTERCARE" 20 "HAVING A BABY" ;
label define AGE_CALC  -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define LOS       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define TRT_DUR   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define ALCOHOL   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER"
                       0 "ALCOHOL USE NOT MENTIONED IN CLIENT RECO"
                       1 "ALCOHOL USE MENTIONED IN CLIENT RECORD" ;
label define DRUG      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 0 "DRUG USE NOT MENTIONED IN CLIENT RECORD"
                       1 "DRUG USE MENTIONED IN CLIENT RECORD" ;
label define DRUG_ALC  -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER"
                       1 "ALCOHOL USE ONLY MENTIONED IN CLIENT REC"
                       2 "BOTH ALCOHOL AND DRUG USE MENTIONED IN C"
                       3 "DRUG USE ONLY MENTIONED IN CLIENT RECORD"
                       4 "UNSPEC SUB USE/NO MENTION OF WHICH SUB A" ;
label define TXCARE    -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "OUTPATIENT METHADONE"
                       2 "OUTPATIENT NON-METHADONE"
                       3 "NON-HOSPITAL RESIDENTIAL" ;
label define ABSSMPTY  -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "D-DISCHARGE EPISODE ANALYSIS GROUP"
                       2 "I-IN-TREATMENT CLIENT ANALYSIS GROUP ("
                       3 "E-EARLY DROP-OUT CLIENT ANALYSIS GROUP" ;
label define QFSTRAT   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 2 "STRATUM 2 RESIDENTIAL"
                       3 "STRATUM 3 PREDOMINANTLY OUTPATIENT METHA"
                       4 "STRATUM 4 OP NON-METH-PREDOMINANTLY ALCO"
                       5 "STRATUM 5 OP NON-METH-NOT IN STRATUM 3 O"
                       6 "STRATUM 6 COMBINATION" ;
label define GROUP     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER"
                       0 "CLIENT TO RECEIVE $15/$10 FOR FOLLOWUP I"
                       1 "CLIENT TO RECEIVE $0/$0 FOR FOLLOWUP INT"
                       2 "CLIENT TO RECEIVE $0/$10 FOR FOLLOWUP IN"
                       3 "CLIENT TO RECEIVE $25/$10 FOR FOLLOWUP I" ;
label define FIELDPSU  -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define U_MRJ_SM  -9 "SKIPPED APPROPRIATELY" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 0 "NEGATIVE" 1 "POSITIVE" ;
label define U_PCP_SM  -9 "SKIPPED APPROPRIATELY" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 0 "NEGATIVE" 1 "POSITIVE" ;
label define U_AMP_SM  -9 "SKIPPED APPROPRIATELY" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 0 "NEGATIVE FOR AMPHETAMINES"
                       1 "POSITIVE FOR AMPHETAMINES" ;
label define U_BEN_SM  -9 "SKIPPED APPROPRIATELY" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 0 "NEGATIVE FOR BENZODIAZEPINES"
                       1 "POSITIVE FOR BENZODIAZEPINES" ;
label define U_COC_SM  -9 "SKIPPED APPROPRIATELY" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 0 "NEGATIVE" 1 "POSITIVE" ;
label define U_MET_SM  -9 "SKIPPED APPROPRIATELY" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 0 "NEGATIVE" 1 "POSITIVE" ;
label define U_OPI_SM  -9 "SKIPPED APPROPRIATELY" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 0 "NEGATIVE FOR OPIATES"
                       1 "POSITIVE FOR AT LEAST ONE OPIATE" ;
label define U_ALCF1   -9 "SKIPPED APPROPRIATELY" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 0 "NEGATIVE" 1 "POSITIVE" ;
label define U_MRJF1   -9 "SKIPPED APPROPRIATELY" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 0 "NEGATIVE" 1 "POSITIVE" ;
label define U_PCPF1   -9 "SKIPPED APPROPRIATELY" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 0 "NEGATIVE" 1 "POSITIVE" ;
label define U_AMPF1   -9 "SKIPPED APPROPRIATELY" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 0 "NEGATIVE" 1 "POSITIVE" ;
label define U_AMPF2   -9 "SKIPPED APPROPRIATELY" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 0 "NEGATIVE" 1 "POSITIVE" ;
label define U_BENF1   -9 "SKIPPED APPROPRIATELY" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 0 "NEGATIVE" 1 "POSITIVE" ;
label define U_BENF2   -9 "SKIPPED APPROPRIATELY" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 0 "NEGATIVE" 1 "POSITIVE" ;
label define U_BENF3   -9 "SKIPPED APPROPRIATELY" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 0 "NEGATIVE" 1 "POSITIVE" ;
label define U_BENF4   -9 "SKIPPED APPROPRIATELY" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 0 "NEGATIVE" 1 "POSITIVE" ;
label define U_BENF5   -9 "SKIPPED APPROPRIATELY" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 0 "NEGATIVE" 1 "POSITIVE" ;
label define U_BENF6   -9 "SKIPPED APPROPRIATELY" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 0 "NEGATIVE" 1 "POSITIVE" ;
label define U_BENF7   -9 "SKIPPED APPROPRIATELY" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 0 "NEGATIVE" 1 "POSITIVE" ;
label define U_BENF8   -9 "SKIPPED APPROPRIATELY" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 0 "NEGATIVE" 1 "POSITIVE" ;
label define U_COCF1   -9 "SKIPPED APPROPRIATELY" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 0 "NEGATIVE" 1 "POSITIVE" ;
label define U_METF1   -9 "SKIPPED APPROPRIATELY" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 0 "NEGATIVE" 1 "POSITIVE" ;
label define U_OPIF1   -9 "SKIPPED APPROPRIATELY" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 0 "NEGATIVE" 1 "POSITIVE" ;
label define U_OPIF2   -9 "SKIPPED APPROPRIATELY" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 0 "NEGATIVE" 1 "POSITIVE" ;
label define U_OPIF3   -9 "SKIPPED APPROPRIATELY" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 0 "NEGATIVE" 1 "POSITIVE" ;
label define U_OPIF4   -9 "SKIPPED APPROPRIATELY" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 0 "NEGATIVE" 1 "POSITIVE" ;
label define U_AMLID   -9 "SKIPPED APPROPRIATELY" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER"
                       31649463 "CHAIN OF CUSTODY DOCUMENT CONTROL NUMBER" ;
label define U_CREATN  -9 "SKIPPED APPROPRIATELY" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define U_PH      -9 "SKIPPED APPROPRIATELY" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "WITHIN ACCEPTABLE RANGE (4.5 - 9)"
                       2 "MISSING" 3 "NOT WITHIN ACCEPTABLE RANGE" ;
label define U_MRJV1   -9 "SKIPPED APPROPRIATELY" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define U_PCPV1   -9 "SKIPPED APPROPRIATELY" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define U_AMPV1   -9 "SKIPPED APPROPRIATELY" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define U_AMPV2   -9 "SKIPPED APPROPRIATELY" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define U_BENV1   -9 "SKIPPED APPROPRIATELY" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define U_BENV2   -9 "SKIPPED APPROPRIATELY" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define U_BENV3   -9 "SKIPPED APPROPRIATELY" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define U_BENV4   -9 "SKIPPED APPROPRIATELY" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define U_BENV5   -9 "SKIPPED APPROPRIATELY" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define U_BENV6   -9 "SKIPPED APPROPRIATELY" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define U_BENV7   -9 "SKIPPED APPROPRIATELY" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define U_BENV8   -9 "SKIPPED APPROPRIATELY" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define U_COCV1   -9 "SKIPPED APPROPRIATELY" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define U_METV1   -9 "SKIPPED APPROPRIATELY" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define U_OPIV1   -9 "SKIPPED APPROPRIATELY" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define U_OPIV2   -9 "SKIPPED APPROPRIATELY" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define U_OPIV3   -9 "SKIPPED APPROPRIATELY" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define U_OPIV4   -9 "SKIPPED APPROPRIATELY" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define U_ALCV1   -9 "SKIPPED APPROPRIATELY" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define U_NITRIT  -9 "SKIPPED APPROPRIATELY" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 0 "NEGATIVE (ACCEPTABLE)" 1 "POSITIVE" ;
label define U_ANYPOS  -9 "SKIPPED APPROPRIATELY" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER"
                       0 "NEGATIVE FOR ALCOHOL AND ALL OTHER DRUGS"
                       1 "POSITIVE FOR EITHER ALCOHOL OR AT LEAST" ;
label define U_ANYDRG  -9 "SKIPPED APPROPRIATELY" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER"
                       0 "NEGATIVE FOR ALL DRUGS OTHER THAN ALCOHO"
                       1 "CONFIRMED POSITIVE FOR AT LEAST ONE DRUG" ;
label define U_NUMDRG  -9 "SKIPPED APPROPRIATELY POSITIVE" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define U_DTDIFF  -9 "SKIPPED APPROPRIATELY" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define U_RESULT  -9 "SKIPPED APPROPRIATELY" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "URINE SAMPLE COLLECTED-VALID RESULTS A"
                       2 "NO RESULTS SPECIMEN COLLECTED NO SIGNED"
                       3 "NO RESULTS SPECIMEN SUBMITTED LAB REPORT"
                       4 "NO RESULTS SPECIMEN SUBMITTED NOT USABLE"
                       5 "NO RESULTS NO SPECIMEN COLLECTED" ;
label define FB33      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FB38      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FC13      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FC16      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FD28      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define FD31      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define RAKFC3    -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define DIM5      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define DIM4      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define DIM3      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define DIM2      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define DIM1      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define PAIR90    -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define CAT_CLI2  -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "NUMBER OF CLIENTS BETWEEN 0 AND 16"
                       2 "NUMBER OF CLIENTS BETWEEN 17 AND 40"
                       3 "NUMBER OF CLIENTS BETWEEN 41 AND 100"
                       4 "NUMBER OF CLIENTS BETWEEN 101 AND 225"
                       5 "NUMBER OF CLIENTS OVER 225" ;
label define CAT_C_D   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "LESS THAN 33.3RD PERCENTILE"
                       2 "BETWEEN 33.3RD AND 66.7TH PERCENTILE"
                       3 "GREATER THAN 66.7TH PERCENTILE" ;
label define PSUTYPE2  -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "METRO CERTAINTY" 2 "METRO NONCERTAINTY"
                       3 "NONMETRO NONCERTAINTY" ;
label define CENREG    -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "NORTHEAST" 2 "MIDWEST" 3 "SOUTH"
                       4 "WEST" ;
label define OWN       -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "PRIVATE FOR PROFIT"
                       2 "PRIVATE NONPROFIT" 3 "PUBLIC" ;
label define VST_PSU   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define VUN_PSU   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define MAIN_WT   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "MISSING" -4 "OTHER" ;
label define C3BWT0    -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define CLTYPE    -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 1 "NONMETHADONE DISCHARGE"
                       2 "METHADONE DISCHARGE" 3 "IN TREATMENT METHADONE" ;
label define DRUG_D81  -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER"
                       1 "REPORT USING 1 OF SUBS IN Q D81 IN 7 DAY"
                       2 "NOT REPORT USING ANY SUBS IN Q. D81 IN 7" ;
label define SELF_C31  -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER"
                       1 "ATTENDED AT LEST 1 SELF HELP GROUP LISTE"
                       2 "DID NOT ATTEND ANY SELF HELP GROUP DURIN" ;
label define CTRIMFLG  -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" 0 "CLIENTS WEIGHT WAS NOT TRIMMED"
                       1 "CLIENTS WEIGHT WAS TRIMMED" ;
label define C3FWT0    -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define CTRMFCTR  -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT1    -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT2    -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT3    -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT4    -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT5    -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT6    -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT7    -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT8    -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT9    -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT10   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT11   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT12   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT13   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT14   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT15   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT16   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT17   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT18   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT19   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT20   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT21   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT22   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT23   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT24   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT25   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT26   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT27   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT28   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT29   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT30   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT31   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT32   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT33   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT34   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT35   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT36   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT37   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT38   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT39   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT40   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT41   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT42   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT43   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT44   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT45   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT46   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT47   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT48   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT49   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT50   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT51   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT52   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT53   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT54   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT55   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT56   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT57   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT58   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT59   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT60   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT61   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT62   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT63   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT64   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT65   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT66   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT67   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT68   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT69   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT70   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT71   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT72   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT73   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT74   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT75   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT76   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT77   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;
label define C3FWT78   -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING"
                       -4 "OTHER" ;


#delimit cr


/***************************************************************************

 Section 4: Missing Values

 This section will replace numeric missing values (i.e., -9) with generic
 system missing ".".  By default the code in this section is commented out.
 Users wishing to apply the generic missing values should remove the comment
 at the beginning and end of this section.  Note that Stata allows you to
 specify up to 27 unique missing value codes.

****************************************************************/

/*
replace CASEID = . if (CASEID <= -1 )
replace FACID = . if (FACID <= -1 )
replace FOUTCOME = . if (FOUTCOME <= -1 )
replace F_CT = . if (F_CT <= -1 )
replace FA1 = . if (FA1 <= -1 )
replace FA3 = . if (FA3 <= -1 )
replace FA4 = . if (FA4 <= -1 )
replace FA5 = . if (FA5 <= -1 )
replace FA6 = . if (FA6 <= -1 )
replace FA7 = . if (FA7 <= -1 )
replace FA8 = . if (FA8 <= -1 )
replace FA9 = . if (FA9 <= -1 )
replace FA10 = . if (FA10 <= -1 )
replace FA11 = . if (FA11 <= -1 )
replace FA12 = . if (FA12 <= -1 )
replace FA12A = . if (FA12A <= -1 )
replace FA13 = . if (FA13 <= -1 )
replace FA14 = . if (FA14 <= -1 )
replace FA15 = . if (FA15 <= -1 )
replace FA16 = . if (FA16 <= -1 )
replace FA17 = . if (FA17 <= -1 )
replace FA18 = . if (FA18 <= -1 )
replace F_LANG = . if (F_LANG <= -1 )
replace FB1A = . if (FB1A <= -1 )
replace FB2A = . if (FB2A <= -1 )
replace FB3A = . if (FB3A <= -1 )
replace FB4A = . if (FB4A <= -1 )
replace FB1B = . if (FB1B <= -1 )
replace FB2B = . if (FB2B <= -1 )
replace FB3B = . if (FB3B <= -1 )
replace FB4B = . if (FB4B <= -1 )
replace FB1C = . if (FB1C <= -1 )
replace FB2C = . if (FB2C <= -1 )
replace FB3C = . if (FB3C <= -1 )
replace FB4C = . if (FB4C <= -1 )
replace FB1D = . if (FB1D <= -1 )
replace FB2D = . if (FB2D <= -1 )
replace FB3D = . if (FB3D <= -1 )
replace FB4D = . if (FB4D <= -1 )
replace FB1E = . if (FB1E <= -1 )
replace FB2E = . if (FB2E <= -1 )
replace FB3E = . if (FB3E <= -1 )
replace FB4E = . if (FB4E <= -1 )
replace FB1F = . if (FB1F <= -1 )
replace FB2F = . if (FB2F <= -1 )
replace FB3F = . if (FB3F <= -1 )
replace FB4F = . if (FB4F <= -1 )
replace FB1G = . if (FB1G <= -1 )
replace FB2G = . if (FB2G <= -1 )
replace FB3G = . if (FB3G <= -1 )
replace FB4G = . if (FB4G <= -1 )
replace FB1H = . if (FB1H <= -1 )
replace FB2H = . if (FB2H <= -1 )
replace FB3H = . if (FB3H <= -1 )
replace FB4H = . if (FB4H <= -1 )
replace FB1I = . if (FB1I <= -1 )
replace FB2I = . if (FB2I <= -1 )
replace FB3I = . if (FB3I <= -1 )
replace FB4I = . if (FB4I <= -1 )
replace FB1J = . if (FB1J <= -1 )
replace FB2J = . if (FB2J <= -1 )
replace FB3J = . if (FB3J <= -1 )
replace FB4J = . if (FB4J <= -1 )
replace FB1K = . if (FB1K <= -1 )
replace FB2K = . if (FB2K <= -1 )
replace FB3K = . if (FB3K <= -1 )
replace FB4K = . if (FB4K <= -1 )
replace FB1L = . if (FB1L <= -1 )
replace FB2L = . if (FB2L <= -1 )
replace FB3L = . if (FB3L <= -1 )
replace FB4L = . if (FB4L <= -1 )
replace FB1M = . if (FB1M <= -1 )
replace FB1MOTH = . if (FB1MOTH <= -1 )
replace FB2M = . if (FB2M <= -1 )
replace FB3M = . if (FB3M <= -1 )
replace FB4M = . if (FB4M <= -1 )
replace FB5 = . if (FB5 <= -1 )
replace FB6 = . if (FB6 <= -1 )
replace FB7 = . if (FB7 <= -1 )
replace FB8 = . if (FB8 <= -1 )
replace FB9 = . if (FB9 <= -1 )
replace FB9A = . if (FB9A <= -1 )
replace FB10 = . if (FB10 <= -1 )
replace FB11 = . if (FB11 <= -1 )
replace FB12A = . if (FB12A <= -1 )
replace FB13A = . if (FB13A <= -1 )
replace FB12B = . if (FB12B <= -1 )
replace FB13B = . if (FB13B <= -1 )
replace FB12C = . if (FB12C <= -1 )
replace FB13C = . if (FB13C <= -1 )
replace FB14 = . if (FB14 <= -1 )
replace FB15 = . if (FB15 <= -1 )
replace FB16 = . if (FB16 <= -1 )
replace FB17 = . if (FB17 <= -1 )
replace FB18 = . if (FB18 <= -1 )
replace FB19 = . if (FB19 <= -1 )
replace FB20 = . if (FB20 <= -1 )
replace FB21 = . if (FB21 <= -1 )
replace FB22 = . if (FB22 <= -1 )
replace FB23 = . if (FB23 <= -1 )
replace FB24 = . if (FB24 <= -1 )
replace FB25 = . if (FB25 <= -1 )
replace FB26 = . if (FB26 <= -1 )
replace FB27A = . if (FB27A <= -1 )
replace FB27B = . if (FB27B <= -1 )
replace FB27C = . if (FB27C <= -1 )
replace FB27D = . if (FB27D <= -1 )
replace FB27E = . if (FB27E <= -1 )
replace FB27F = . if (FB27F <= -1 )
replace FB27G = . if (FB27G <= -1 )
replace FB28 = . if (FB28 <= -1 )
replace FB29 = . if (FB29 <= -1 )
replace FB30 = . if (FB30 <= -1 )
replace FB31 = . if (FB31 <= -1 )
replace FB32 = . if (FB32 <= -1 )
replace FB33A = . if (FB33A <= -1 )
replace FB33AOTH = . if (FB33AOTH <= -1 )
replace FB34 = . if (FB34 <= -1 )
replace FB34A = . if (FB34A <= -1 )
replace FB35 = . if (FB35 <= -1 )
replace FB36 = . if (FB36 <= -1 )
replace FB37 = . if (FB37 <= -1 )
replace FB38A = . if (FB38A <= -1 )
replace FB38AOTH = . if (FB38AOTH <= -1 )
replace FB39 = . if (FB39 <= -1 )
replace FB40 = . if (FB40 <= -1 )
replace FB41 = . if (FB41 <= -1 )
replace FB42A = . if (FB42A <= -1 )
replace FB42B = . if (FB42B <= -1 )
replace FB42C = . if (FB42C <= -1 )
replace FB42D = . if (FB42D <= -1 )
replace FB42E = . if (FB42E <= -1 )
replace FB42F = . if (FB42F <= -1 )
replace FB42G = . if (FB42G <= -1 )
replace FB42H = . if (FB42H <= -1 )
replace FB42I = . if (FB42I <= -1 )
replace FB42J = . if (FB42J <= -1 )
replace FB42K = . if (FB42K <= -1 )
replace FB42L = . if (FB42L <= -1 )
replace FB43 = . if (FB43 <= -1 )
replace FB44 = . if (FB44 <= -1 )
replace FB44A = . if (FB44A <= -1 )
replace FB44B = . if (FB44B <= -1 )
replace FB45 = . if (FB45 <= -1 )
replace FB46A = . if (FB46A <= -1 )
replace FB47A = . if (FB47A <= -1 )
replace FB46B = . if (FB46B <= -1 )
replace FB47B = . if (FB47B <= -1 )
replace FB46C = . if (FB46C <= -1 )
replace FB47C = . if (FB47C <= -1 )
replace FB46D = . if (FB46D <= -1 )
replace FB47D = . if (FB47D <= -1 )
replace FB46E = . if (FB46E <= -1 )
replace FB47E = . if (FB47E <= -1 )
replace FB46F = . if (FB46F <= -1 )
replace FB47F = . if (FB47F <= -1 )
replace FB46G = . if (FB46G <= -1 )
replace FB47G = . if (FB47G <= -1 )
replace FB46H = . if (FB46H <= -1 )
replace FB47H = . if (FB47H <= -1 )
replace FB48A = . if (FB48A <= -1 )
replace FB49A = . if (FB49A <= -1 )
replace FB48B = . if (FB48B <= -1 )
replace FB49B = . if (FB49B <= -1 )
replace FB48C = . if (FB48C <= -1 )
replace FB49C = . if (FB49C <= -1 )
replace FB48D = . if (FB48D <= -1 )
replace FB49D = . if (FB49D <= -1 )
replace FB48E = . if (FB48E <= -1 )
replace FB49E = . if (FB49E <= -1 )
replace FB48F = . if (FB48F <= -1 )
replace FB49F = . if (FB49F <= -1 )
replace FB48G = . if (FB48G <= -1 )
replace FB49G = . if (FB49G <= -1 )
replace FB48H = . if (FB48H <= -1 )
replace FB49H = . if (FB49H <= -1 )
replace FB50A = . if (FB50A <= -1 )
replace FB50B = . if (FB50B <= -1 )
replace FB50C = . if (FB50C <= -1 )
replace FB50D = . if (FB50D <= -1 )
replace FB51A = . if (FB51A <= -1 )
replace FB52A = . if (FB52A <= -1 )
replace FB53A = . if (FB53A <= -1 )
replace FB51B = . if (FB51B <= -1 )
replace FB52B = . if (FB52B <= -1 )
replace FB53B = . if (FB53B <= -1 )
replace FB51C = . if (FB51C <= -1 )
replace FB52C = . if (FB52C <= -1 )
replace FB53C = . if (FB53C <= -1 )
replace FB51D = . if (FB51D <= -1 )
replace FB52D = . if (FB52D <= -1 )
replace FB53D = . if (FB53D <= -1 )
replace FB54 = . if (FB54 <= -1 )
replace FB55 = . if (FB55 <= -1 )
replace FB56 = . if (FB56 <= -1 )
replace FB57 = . if (FB57 <= -1 )
replace FB58 = . if (FB58 <= -1 )
replace FB59 = . if (FB59 <= -1 )
replace FB60 = . if (FB60 <= -1 )
replace FB61 = . if (FB61 <= -1 )
replace FB62 = . if (FB62 <= -1 )
replace FB63 = . if (FB63 <= -1 )
replace FB64A = . if (FB64A <= -1 )
replace FB65A = . if (FB65A <= -1 )
replace FB64B = . if (FB64B <= -1 )
replace FB65B = . if (FB65B <= -1 )
replace FB64C = . if (FB64C <= -1 )
replace FB65C = . if (FB65C <= -1 )
replace FB64D = . if (FB64D <= -1 )
replace FB65D = . if (FB65D <= -1 )
replace FB64E = . if (FB64E <= -1 )
replace FB65E = . if (FB65E <= -1 )
replace FB64F = . if (FB64F <= -1 )
replace FB65F = . if (FB65F <= -1 )
replace FB64G = . if (FB64G <= -1 )
replace FB65G = . if (FB65G <= -1 )
replace FB64H = . if (FB64H <= -1 )
replace FB65H = . if (FB65H <= -1 )
replace FB64I = . if (FB64I <= -1 )
replace FB65I = . if (FB65I <= -1 )
replace FB64J = . if (FB64J <= -1 )
replace FB65J = . if (FB65J <= -1 )
replace FB64K = . if (FB64K <= -1 )
replace FB65K = . if (FB65K <= -1 )
replace FB64L = . if (FB64L <= -1 )
replace FB65L = . if (FB65L <= -1 )
replace FB64M = . if (FB64M <= -1 )
replace FB65M = . if (FB65M <= -1 )
replace FB66 = . if (FB66 <= -1 )
replace FB67 = . if (FB67 <= -1 )
replace FB68 = . if (FB68 <= -1 )
replace FB69 = . if (FB69 <= -1 )
replace FB70 = . if (FB70 <= -1 )
replace FB71 = . if (FB71 <= -1 )
replace FB72 = . if (FB72 <= -1 )
replace FB73 = . if (FB73 <= -1 )
replace FB74 = . if (FB74 <= -1 )
replace FB75 = . if (FB75 <= -1 )
replace FB76 = . if (FB76 <= -1 )
replace FB77A = . if (FB77A <= -1 )
replace FB77B = . if (FB77B <= -1 )
replace FB77C = . if (FB77C <= -1 )
replace FB78 = . if (FB78 <= -1 )
replace FB78A = . if (FB78A <= -1 )
replace FB79 = . if (FB79 <= -1 )
replace FB80 = . if (FB80 <= -1 )
replace FB81A = . if (FB81A <= -1 )
replace FB82A = . if (FB82A <= -1 )
replace FB83A = . if (FB83A <= -1 )
replace FB84A = . if (FB84A <= -1 )
replace FB85A = . if (FB85A <= -1 )
replace FB81B = . if (FB81B <= -1 )
replace FB82B = . if (FB82B <= -1 )
replace FB83B = . if (FB83B <= -1 )
replace FB84B = . if (FB84B <= -1 )
replace FB85B = . if (FB85B <= -1 )
replace FB81C = . if (FB81C <= -1 )
replace FB82C = . if (FB82C <= -1 )
replace FB83C = . if (FB83C <= -1 )
replace FB84C = . if (FB84C <= -1 )
replace FB85C = . if (FB85C <= -1 )
replace FB81D = . if (FB81D <= -1 )
replace FB82D = . if (FB82D <= -1 )
replace FB83D = . if (FB83D <= -1 )
replace FB84D = . if (FB84D <= -1 )
replace FB85D = . if (FB85D <= -1 )
replace FB81E = . if (FB81E <= -1 )
replace FB82E = . if (FB82E <= -1 )
replace FB83E = . if (FB83E <= -1 )
replace FB84E = . if (FB84E <= -1 )
replace FB85E = . if (FB85E <= -1 )
replace FB81F = . if (FB81F <= -1 )
replace FB82F = . if (FB82F <= -1 )
replace FB83F = . if (FB83F <= -1 )
replace FB84F = . if (FB84F <= -1 )
replace FB85F = . if (FB85F <= -1 )
replace FB81G = . if (FB81G <= -1 )
replace FB82G = . if (FB82G <= -1 )
replace FB83G = . if (FB83G <= -1 )
replace FB84G = . if (FB84G <= -1 )
replace FB85G = . if (FB85G <= -1 )
replace FB81H = . if (FB81H <= -1 )
replace FB82H = . if (FB82H <= -1 )
replace FB83H = . if (FB83H <= -1 )
replace FB84H = . if (FB84H <= -1 )
replace FB85H = . if (FB85H <= -1 )
replace FB81I = . if (FB81I <= -1 )
replace FB82I = . if (FB82I <= -1 )
replace FB83I = . if (FB83I <= -1 )
replace FB84I = . if (FB84I <= -1 )
replace FB85I = . if (FB85I <= -1 )
replace FB81J = . if (FB81J <= -1 )
replace FB82J = . if (FB82J <= -1 )
replace FB83J = . if (FB83J <= -1 )
replace FB84J = . if (FB84J <= -1 )
replace FB85J = . if (FB85J <= -1 )
replace FB81K = . if (FB81K <= -1 )
replace FB82K = . if (FB82K <= -1 )
replace FB83K = . if (FB83K <= -1 )
replace FB84K = . if (FB84K <= -1 )
replace FB85K = . if (FB85K <= -1 )
replace FB81L = . if (FB81L <= -1 )
replace FB82L = . if (FB82L <= -1 )
replace FB83L = . if (FB83L <= -1 )
replace FB84L = . if (FB84L <= -1 )
replace FB85L = . if (FB85L <= -1 )
replace FB81M = . if (FB81M <= -1 )
replace FB82M = . if (FB82M <= -1 )
replace FB83M = . if (FB83M <= -1 )
replace FB84M = . if (FB84M <= -1 )
replace FB85M = . if (FB85M <= -1 )
replace FB81N = . if (FB81N <= -1 )
replace FB81NOTH = . if (FB81NOTH <= -1 )
replace FB82N = . if (FB82N <= -1 )
replace FB83N = . if (FB83N <= -1 )
replace FB84N = . if (FB84N <= -1 )
replace FB85N = . if (FB85N <= -1 )
replace FB86 = . if (FB86 <= -1 )
replace FB87 = . if (FB87 <= -1 )
replace FB88 = . if (FB88 <= -1 )
replace FB89 = . if (FB89 <= -1 )
replace FB90 = . if (FB90 <= -1 )
replace FB91 = . if (FB91 <= -1 )
replace FB91U = . if (FB91U <= -1 )
replace FB92 = . if (FB92 <= -1 )
replace FB93 = . if (FB93 <= -1 )
replace FB93U = . if (FB93U <= -1 )
replace FB94 = . if (FB94 <= -1 )
replace FB95 = . if (FB95 <= -1 )
replace FB95A = . if (FB95A <= -1 )
replace FC1 = . if (FC1 <= -1 )
replace FC2 = . if (FC2 <= -1 )
replace FC3 = . if (FC3 <= -1 )
replace FC4 = . if (FC4 <= -1 )
replace FC5 = . if (FC5 <= -1 )
replace FC6 = . if (FC6 <= -1 )
replace FC6A = . if (FC6A <= -1 )
replace FC7A = . if (FC7A <= -1 )
replace FC7B = . if (FC7B <= -1 )
replace FC7C = . if (FC7C <= -1 )
replace FC7D = . if (FC7D <= -1 )
replace FC7E = . if (FC7E <= -1 )
replace FC7F = . if (FC7F <= -1 )
replace FC8 = . if (FC8 <= -1 )
replace FC8A = . if (FC8A <= -1 )
replace FC9 = . if (FC9 <= -1 )
replace FC10 = . if (FC10 <= -1 )
replace FC11 = . if (FC11 <= -1 )
replace FC11U = . if (FC11U <= -1 )
replace FC12 = . if (FC12 <= -1 )
replace FC13A = . if (FC13A <= -1 )
replace FC13AOTH = . if (FC13AOTH <= -1 )
replace FC14 = . if (FC14 <= -1 )
replace FC15 = . if (FC15 <= -1 )
replace FC15U = . if (FC15U <= -1 )
replace FC16A = . if (FC16A <= -1 )
replace FC16AOTH = . if (FC16AOTH <= -1 )
replace FC17 = . if (FC17 <= -1 )
replace FC18 = . if (FC18 <= -1 )
replace FC19 = . if (FC19 <= -1 )
replace FC20 = . if (FC20 <= -1 )
replace FC21 = . if (FC21 <= -1 )
replace FC22 = . if (FC22 <= -1 )
replace FC24A = . if (FC24A <= -1 )
replace FC25A = . if (FC25A <= -1 )
replace FC24B = . if (FC24B <= -1 )
replace FC25B = . if (FC25B <= -1 )
replace FC24C = . if (FC24C <= -1 )
replace FC25C = . if (FC25C <= -1 )
replace FC24D = . if (FC24D <= -1 )
replace FC25D = . if (FC25D <= -1 )
replace FC24E = . if (FC24E <= -1 )
replace FC25E = . if (FC25E <= -1 )
replace FC24F = . if (FC24F <= -1 )
replace FC25F = . if (FC25F <= -1 )
replace FC24G = . if (FC24G <= -1 )
replace FC25G = . if (FC25G <= -1 )
replace FC24H = . if (FC24H <= -1 )
replace FC25H = . if (FC25H <= -1 )
replace FC24I = . if (FC24I <= -1 )
replace FC25I = . if (FC25I <= -1 )
replace FC24J = . if (FC24J <= -1 )
replace FC25J = . if (FC25J <= -1 )
replace FC24K = . if (FC24K <= -1 )
replace FC25K = . if (FC25K <= -1 )
replace FC24L = . if (FC24L <= -1 )
replace FC25L = . if (FC25L <= -1 )
replace FC24M = . if (FC24M <= -1 )
replace FC25M = . if (FC25M <= -1 )
replace FC24N = . if (FC24N <= -1 )
replace FC25N = . if (FC25N <= -1 )
replace FC24O = . if (FC24O <= -1 )
replace FC25O = . if (FC25O <= -1 )
replace FC24P = . if (FC24P <= -1 )
replace FC25P = . if (FC25P <= -1 )
replace FC24Q = . if (FC24Q <= -1 )
replace FC25Q = . if (FC25Q <= -1 )
replace FC24R = . if (FC24R <= -1 )
replace FC25R = . if (FC25R <= -1 )
replace FC24S = . if (FC24S <= -1 )
replace FC25S = . if (FC25S <= -1 )
replace FC24T = . if (FC24T <= -1 )
replace FC25T = . if (FC25T <= -1 )
replace FC26 = . if (FC26 <= -1 )
replace FC27 = . if (FC27 <= -1 )
replace FC28 = . if (FC28 <= -1 )
replace FC29A = . if (FC29A <= -1 )
replace FC29B = . if (FC29B <= -1 )
replace FC29C = . if (FC29C <= -1 )
replace FC29D = . if (FC29D <= -1 )
replace FC29E = . if (FC29E <= -1 )
replace FC29F = . if (FC29F <= -1 )
replace FC29G = . if (FC29G <= -1 )
replace FC29H = . if (FC29H <= -1 )
replace FC29I = . if (FC29I <= -1 )
replace FC29J = . if (FC29J <= -1 )
replace FC29K = . if (FC29K <= -1 )
replace FC29L = . if (FC29L <= -1 )
replace FC29M = . if (FC29M <= -1 )
replace FC29N = . if (FC29N <= -1 )
replace FC29O = . if (FC29O <= -1 )
replace FC30A = . if (FC30A <= -1 )
replace FC30B = . if (FC30B <= -1 )
replace FC30C = . if (FC30C <= -1 )
replace FC30D = . if (FC30D <= -1 )
replace FC30E = . if (FC30E <= -1 )
replace FC30EOTH = . if (FC30EOTH <= -1 )
replace FC31A = . if (FC31A <= -1 )
replace FC32A = . if (FC32A <= -1 )
replace FC33A = . if (FC33A <= -1 )
replace FC31B = . if (FC31B <= -1 )
replace FC32B = . if (FC32B <= -1 )
replace FC33B = . if (FC33B <= -1 )
replace FC31C = . if (FC31C <= -1 )
replace FC32C = . if (FC32C <= -1 )
replace FC33C = . if (FC33C <= -1 )
replace FC31D = . if (FC31D <= -1 )
replace FC32D = . if (FC32D <= -1 )
replace FC33D = . if (FC33D <= -1 )
replace FC34 = . if (FC34 <= -1 )
replace FC35 = . if (FC35 <= -1 )
replace FC35OTH = . if (FC35OTH <= -1 )
replace FC36 = . if (FC36 <= -1 )
replace FC37 = . if (FC37 <= -1 )
replace FC38 = . if (FC38 <= -1 )
replace FC39 = . if (FC39 <= -1 )
replace FC40 = . if (FC40 <= -1 )
replace FC41 = . if (FC41 <= -1 )
replace FC42 = . if (FC42 <= -1 )
replace FC43 = . if (FC43 <= -1 )
replace FC44 = . if (FC44 <= -1 )
replace FC45 = . if (FC45 <= -1 )
replace FC46 = . if (FC46 <= -1 )
replace FC47 = . if (FC47 <= -1 )
replace FC48 = . if (FC48 <= -1 )
replace FC49 = . if (FC49 <= -1 )
replace FC50 = . if (FC50 <= -1 )
replace FC51 = . if (FC51 <= -1 )
replace FC52 = . if (FC52 <= -1 )
replace FC53 = . if (FC53 <= -1 )
replace FC54 = . if (FC54 <= -1 )
replace FC55 = . if (FC55 <= -1 )
replace FC56 = . if (FC56 <= -1 )
replace FC57 = . if (FC57 <= -1 )
replace FC58 = . if (FC58 <= -1 )
replace FC58U = . if (FC58U <= -1 )
replace FC59 = . if (FC59 <= -1 )
replace FC60A = . if (FC60A <= -1 )
replace FC60B = . if (FC60B <= -1 )
replace FC60C = . if (FC60C <= -1 )
replace FC60D = . if (FC60D <= -1 )
replace FC60E = . if (FC60E <= -1 )
replace FC60F = . if (FC60F <= -1 )
replace FC61A = . if (FC61A <= -1 )
replace FC61B = . if (FC61B <= -1 )
replace FC61C = . if (FC61C <= -1 )
replace FC61D = . if (FC61D <= -1 )
replace FC61E = . if (FC61E <= -1 )
replace FC61F = . if (FC61F <= -1 )
replace FC61G = . if (FC61G <= -1 )
replace FC61H = . if (FC61H <= -1 )
replace FC61I = . if (FC61I <= -1 )
replace FC61J = . if (FC61J <= -1 )
replace FC61JOTH = . if (FC61JOTH <= -1 )
replace FC61MAIN = . if (FC61MAIN <= -1 )
replace FC62A = . if (FC62A <= -1 )
replace FC62B = . if (FC62B <= -1 )
replace FC62C = . if (FC62C <= -1 )
replace FC62D = . if (FC62D <= -1 )
replace FC62E = . if (FC62E <= -1 )
replace FC62F = . if (FC62F <= -1 )
replace FC62G = . if (FC62G <= -1 )
replace FC62H = . if (FC62H <= -1 )
replace FC62I = . if (FC62I <= -1 )
replace FC62J = . if (FC62J <= -1 )
replace FC62K = . if (FC62K <= -1 )
replace FC62L = . if (FC62L <= -1 )
replace FD1A = . if (FD1A <= -1 )
replace FD2A = . if (FD2A <= -1 )
replace FD3A = . if (FD3A <= -1 )
replace FD4A = . if (FD4A <= -1 )
replace FD1B = . if (FD1B <= -1 )
replace FD2B = . if (FD2B <= -1 )
replace FD3B = . if (FD3B <= -1 )
replace FD4B = . if (FD4B <= -1 )
replace FD1C = . if (FD1C <= -1 )
replace FD2C = . if (FD2C <= -1 )
replace FD3C = . if (FD3C <= -1 )
replace FD4C = . if (FD4C <= -1 )
replace FD1D = . if (FD1D <= -1 )
replace FD2D = . if (FD2D <= -1 )
replace FD3D = . if (FD3D <= -1 )
replace FD4D = . if (FD4D <= -1 )
replace FD1E = . if (FD1E <= -1 )
replace FD2E = . if (FD2E <= -1 )
replace FD3E = . if (FD3E <= -1 )
replace FD4E = . if (FD4E <= -1 )
replace FD1F = . if (FD1F <= -1 )
replace FD2F = . if (FD2F <= -1 )
replace FD3F = . if (FD3F <= -1 )
replace FD4F = . if (FD4F <= -1 )
replace FD1G = . if (FD1G <= -1 )
replace FD2G = . if (FD2G <= -1 )
replace FD3G = . if (FD3G <= -1 )
replace FD4G = . if (FD4G <= -1 )
replace FD1H = . if (FD1H <= -1 )
replace FD2H = . if (FD2H <= -1 )
replace FD3H = . if (FD3H <= -1 )
replace FD4H = . if (FD4H <= -1 )
replace FD1I = . if (FD1I <= -1 )
replace FD2I = . if (FD2I <= -1 )
replace FD3I = . if (FD3I <= -1 )
replace FD4I = . if (FD4I <= -1 )
replace FD1J = . if (FD1J <= -1 )
replace FD2J = . if (FD2J <= -1 )
replace FD3J = . if (FD3J <= -1 )
replace FD4J = . if (FD4J <= -1 )
replace FD1K = . if (FD1K <= -1 )
replace FD2K = . if (FD2K <= -1 )
replace FD3K = . if (FD3K <= -1 )
replace FD4K = . if (FD4K <= -1 )
replace FD1L = . if (FD1L <= -1 )
replace FD2L = . if (FD2L <= -1 )
replace FD3L = . if (FD3L <= -1 )
replace FD4L = . if (FD4L <= -1 )
replace FD1M = . if (FD1M <= -1 )
replace FD1MOTH1 = . if (FD1MOTH1 <= -1 )
replace FD2MOTH1 = . if (FD2MOTH1 <= -1 )
replace FD3MOTH1 = . if (FD3MOTH1 <= -1 )
replace FD4MOTH1 = . if (FD4MOTH1 <= -1 )
replace FD1MOTH2 = . if (FD1MOTH2 <= -1 )
replace FD2MOTH2 = . if (FD2MOTH2 <= -1 )
replace FD3MOTH2 = . if (FD3MOTH2 <= -1 )
replace FD4MOTH2 = . if (FD4MOTH2 <= -1 )
replace FD1MOTH3 = . if (FD1MOTH3 <= -1 )
replace FD2MOTH3 = . if (FD2MOTH3 <= -1 )
replace FD3MOTH3 = . if (FD3MOTH3 <= -1 )
replace FD4MOTH3 = . if (FD4MOTH3 <= -1 )
replace FD5 = . if (FD5 <= -1 )
replace FD6 = . if (FD6 <= -1 )
replace FD7 = . if (FD7 <= -1 )
replace FD8 = . if (FD8 <= -1 )
replace FD9 = . if (FD9 <= -1 )
replace FD10 = . if (FD10 <= -1 )
replace FD11 = . if (FD11 <= -1 )
replace FD12A = . if (FD12A <= -1 )
replace FD13A = . if (FD13A <= -1 )
replace FD12B = . if (FD12B <= -1 )
replace FD13B = . if (FD13B <= -1 )
replace FD12C = . if (FD12C <= -1 )
replace FD13C = . if (FD13C <= -1 )
replace FD14 = . if (FD14 <= -1 )
replace FD15 = . if (FD15 <= -1 )
replace FD16 = . if (FD16 <= -1 )
replace FD17 = . if (FD17 <= -1 )
replace FD18 = . if (FD18 <= -1 )
replace FD19 = . if (FD19 <= -1 )
replace FD20 = . if (FD20 <= -1 )
replace FD21 = . if (FD21 <= -1 )
replace FD23A = . if (FD23A <= -1 )
replace FD23B = . if (FD23B <= -1 )
replace FD23C = . if (FD23C <= -1 )
replace FD23D = . if (FD23D <= -1 )
replace FD23E = . if (FD23E <= -1 )
replace FD23F = . if (FD23F <= -1 )
replace FD23G = . if (FD23G <= -1 )
replace FD24 = . if (FD24 <= -1 )
replace FD25 = . if (FD25 <= -1 )
replace FD26 = . if (FD26 <= -1 )
replace FD27 = . if (FD27 <= -1 )
replace FD28A = . if (FD28A <= -1 )
replace FD28AOTH = . if (FD28AOTH <= -1 )
replace FD29 = . if (FD29 <= -1 )
replace FD30 = . if (FD30 <= -1 )
replace FD31A = . if (FD31A <= -1 )
replace FD31AOTH = . if (FD31AOTH <= -1 )
replace FD32A = . if (FD32A <= -1 )
replace FD32B = . if (FD32B <= -1 )
replace FD32C = . if (FD32C <= -1 )
replace FD32D = . if (FD32D <= -1 )
replace FD32E = . if (FD32E <= -1 )
replace FD32F = . if (FD32F <= -1 )
replace FD32G = . if (FD32G <= -1 )
replace FD32H = . if (FD32H <= -1 )
replace FD32I = . if (FD32I <= -1 )
replace FD32J = . if (FD32J <= -1 )
replace FD32K = . if (FD32K <= -1 )
replace FD32L = . if (FD32L <= -1 )
replace FD33A = . if (FD33A <= -1 )
replace FD33B = . if (FD33B <= -1 )
replace FD33C = . if (FD33C <= -1 )
replace FD33D = . if (FD33D <= -1 )
replace FD33E = . if (FD33E <= -1 )
replace FD33F = . if (FD33F <= -1 )
replace FD34A = . if (FD34A <= -1 )
replace FD34B = . if (FD34B <= -1 )
replace FD34C = . if (FD34C <= -1 )
replace FD34D = . if (FD34D <= -1 )
replace FD34E = . if (FD34E <= -1 )
replace FD35 = . if (FD35 <= -1 )
replace FD37A = . if (FD37A <= -1 )
replace FD38A = . if (FD38A <= -1 )
replace FD37B = . if (FD37B <= -1 )
replace FD38B = . if (FD38B <= -1 )
replace FD37C = . if (FD37C <= -1 )
replace FD38C = . if (FD38C <= -1 )
replace FD37D = . if (FD37D <= -1 )
replace FD38D = . if (FD38D <= -1 )
replace FD37E = . if (FD37E <= -1 )
replace FD38E = . if (FD38E <= -1 )
replace FD37F = . if (FD37F <= -1 )
replace FD38F = . if (FD38F <= -1 )
replace FD37G = . if (FD37G <= -1 )
replace FD38G = . if (FD38G <= -1 )
replace FD37H = . if (FD37H <= -1 )
replace FD38H = . if (FD38H <= -1 )
replace FD39A = . if (FD39A <= -1 )
replace FD40A = . if (FD40A <= -1 )
replace FD41A = . if (FD41A <= -1 )
replace FD39B = . if (FD39B <= -1 )
replace FD40B = . if (FD40B <= -1 )
replace FD41B = . if (FD41B <= -1 )
replace FD39C = . if (FD39C <= -1 )
replace FD40C = . if (FD40C <= -1 )
replace FD41C = . if (FD41C <= -1 )
replace FD39D = . if (FD39D <= -1 )
replace FD40D = . if (FD40D <= -1 )
replace FD41D = . if (FD41D <= -1 )
replace FD42 = . if (FD42 <= -1 )
replace FD42A = . if (FD42A <= -1 )
replace FD42B = . if (FD42B <= -1 )
replace FD42C = . if (FD42C <= -1 )
replace FD42D = . if (FD42D <= -1 )
replace FD42E = . if (FD42E <= -1 )
replace FD42F = . if (FD42F <= -1 )
replace FD42G = . if (FD42G <= -1 )
replace FD42H = . if (FD42H <= -1 )
replace FD42I = . if (FD42I <= -1 )
replace FD43 = . if (FD43 <= -1 )
replace FD44 = . if (FD44 <= -1 )
replace FD45 = . if (FD45 <= -1 )
replace FD46 = . if (FD46 <= -1 )
replace FD47 = . if (FD47 <= -1 )
replace FD48 = . if (FD48 <= -1 )
replace FD49A = . if (FD49A <= -1 )
replace FD49B = . if (FD49B <= -1 )
replace FD49C = . if (FD49C <= -1 )
replace FD49D = . if (FD49D <= -1 )
replace FD49E = . if (FD49E <= -1 )
replace FD49F = . if (FD49F <= -1 )
replace FD49G = . if (FD49G <= -1 )
replace FD49H = . if (FD49H <= -1 )
replace FD49I = . if (FD49I <= -1 )
replace FD49J = . if (FD49J <= -1 )
replace FD49K = . if (FD49K <= -1 )
replace FD49L = . if (FD49L <= -1 )
replace FD49M = . if (FD49M <= -1 )
replace FD50 = . if (FD50 <= -1 )
replace FD51 = . if (FD51 <= -1 )
replace FD52 = . if (FD52 <= -1 )
replace FD53 = . if (FD53 <= -1 )
replace FD54 = . if (FD54 <= -1 )
replace FD55 = . if (FD55 <= -1 )
replace FD56 = . if (FD56 <= -1 )
replace FD57 = . if (FD57 <= -1 )
replace FD58 = . if (FD58 <= -1 )
replace FD59 = . if (FD59 <= -1 )
replace FD60 = . if (FD60 <= -1 )
replace FD61A = . if (FD61A <= -1 )
replace FD61B = . if (FD61B <= -1 )
replace FD61C = . if (FD61C <= -1 )
replace FD62 = . if (FD62 <= -1 )
replace FD63 = . if (FD63 <= -1 )
replace FD64 = . if (FD64 <= -1 )
replace FD65 = . if (FD65 <= -1 )
replace FD66 = . if (FD66 <= -1 )
replace FD67 = . if (FD67 <= -1 )
replace FD68A = . if (FD68A <= -1 )
replace FD69A = . if (FD69A <= -1 )
replace FD68B = . if (FD68B <= -1 )
replace FD69B = . if (FD69B <= -1 )
replace FD68C = . if (FD68C <= -1 )
replace FD69C = . if (FD69C <= -1 )
replace FD68D = . if (FD68D <= -1 )
replace FD69D = . if (FD69D <= -1 )
replace FD68E = . if (FD68E <= -1 )
replace FD69E = . if (FD69E <= -1 )
replace FD68F = . if (FD68F <= -1 )
replace FD69F = . if (FD69F <= -1 )
replace FD68G = . if (FD68G <= -1 )
replace FD69G = . if (FD69G <= -1 )
replace FD68H = . if (FD68H <= -1 )
replace FD69H = . if (FD69H <= -1 )
replace FD68I = . if (FD68I <= -1 )
replace FD69I = . if (FD69I <= -1 )
replace FD68J = . if (FD68J <= -1 )
replace FD69J = . if (FD69J <= -1 )
replace FD68K = . if (FD68K <= -1 )
replace FD69K = . if (FD69K <= -1 )
replace FD68L = . if (FD68L <= -1 )
replace FD69L = . if (FD69L <= -1 )
replace FD68M = . if (FD68M <= -1 )
replace FD69M = . if (FD69M <= -1 )
replace FD68N = . if (FD68N <= -1 )
replace FD68NOTH = . if (FD68NOTH <= -1 )
replace FD69N = . if (FD69N <= -1 )
replace FD70 = . if (FD70 <= -1 )
replace FD71 = . if (FD71 <= -1 )
replace FD72 = . if (FD72 <= -1 )
replace FD73 = . if (FD73 <= -1 )
replace FD74 = . if (FD74 <= -1 )
replace FD75 = . if (FD75 <= -1 )
replace FD75U = . if (FD75U <= -1 )
replace FD76 = . if (FD76 <= -1 )
replace FD77 = . if (FD77 <= -1 )
replace FD78 = . if (FD78 <= -1 )
replace FD79 = . if (FD79 <= -1 )
replace FD80 = . if (FD80 <= -1 )
replace FD81A = . if (FD81A <= -1 )
replace FD82A = . if (FD82A <= -1 )
replace FD83A = . if (FD83A <= -1 )
replace FD81B = . if (FD81B <= -1 )
replace FD82B = . if (FD82B <= -1 )
replace FD83B = . if (FD83B <= -1 )
replace FD81C = . if (FD81C <= -1 )
replace FD82C = . if (FD82C <= -1 )
replace FD83C = . if (FD83C <= -1 )
replace FD81D = . if (FD81D <= -1 )
replace FD82D = . if (FD82D <= -1 )
replace FD83D = . if (FD83D <= -1 )
replace FD81E = . if (FD81E <= -1 )
replace FD82E = . if (FD82E <= -1 )
replace FD83E = . if (FD83E <= -1 )
replace FD81F = . if (FD81F <= -1 )
replace FD82F = . if (FD82F <= -1 )
replace FD83F = . if (FD83F <= -1 )
replace FD81G = . if (FD81G <= -1 )
replace FD82G = . if (FD82G <= -1 )
replace FD83G = . if (FD83G <= -1 )
replace FD81H = . if (FD81H <= -1 )
replace FD82H = . if (FD82H <= -1 )
replace FD83H = . if (FD83H <= -1 )
replace FD81I = . if (FD81I <= -1 )
replace FD82I = . if (FD82I <= -1 )
replace FD83I = . if (FD83I <= -1 )
replace FD84A = . if (FD84A <= -1 )
replace FD84B = . if (FD84B <= -1 )
replace FD84C = . if (FD84C <= -1 )
replace FD84D = . if (FD84D <= -1 )
replace FD84E = . if (FD84E <= -1 )
replace FD84F = . if (FD84F <= -1 )
replace FD84G = . if (FD84G <= -1 )
replace FB2CFLG = . if (FB2CFLG <= -1 )
replace FB2FFLG = . if (FB2FFLG <= -1 )
replace FB2KFLG = . if (FB2KFLG <= -1 )
replace FB82AFLG = . if (FB82AFLG <= -1 )
replace FB82BFLG = . if (FB82BFLG <= -1 )
replace FB82CFLG = . if (FB82CFLG <= -1 )
replace FB82DFLG = . if (FB82DFLG <= -1 )
replace FB82EFLG = . if (FB82EFLG <= -1 )
replace FB82FFLG = . if (FB82FFLG <= -1 )
replace FB82GFLG = . if (FB82GFLG <= -1 )
replace FB82HFLG = . if (FB82HFLG <= -1 )
replace FB82IFLG = . if (FB82IFLG <= -1 )
replace FB82JFLG = . if (FB82JFLG <= -1 )
replace FB82KFLG = . if (FB82KFLG <= -1 )
replace FB82LFLG = . if (FB82LFLG <= -1 )
replace FB82MFLG = . if (FB82MFLG <= -1 )
replace FB82NFLG = . if (FB82NFLG <= -1 )
replace FB88AFLG = . if (FB88AFLG <= -1 )
replace FD36FLG = . if (FD36FLG <= -1 )
replace FD3BFLG = . if (FD3BFLG <= -1 )
replace FD3CFLG = . if (FD3CFLG <= -1 )
replace FD3DFLG = . if (FD3DFLG <= -1 )
replace FD3EFLG = . if (FD3EFLG <= -1 )
replace FD3FFLG = . if (FD3FFLG <= -1 )
replace FD3GFLG = . if (FD3GFLG <= -1 )
replace FD3IFLG = . if (FD3IFLG <= -1 )
replace FD38BFLG = . if (FD38BFLG <= -1 )
replace FD38CFLG = . if (FD38CFLG <= -1 )
replace FD38DFLG = . if (FD38DFLG <= -1 )
replace FD38FFLG = . if (FD38FFLG <= -1 )
replace FD38GFLG = . if (FD38GFLG <= -1 )
replace FD38HFLG = . if (FD38HFLG <= -1 )
replace FD5FLG = . if (FD5FLG <= -1 )
replace FD26FLG = . if (FD26FLG <= -1 )
replace FD30FLG = . if (FD30FLG <= -1 )
replace FD40AFLG = . if (FD40AFLG <= -1 )
replace FD40BFLG = . if (FD40BFLG <= -1 )
replace FD40CFLG = . if (FD40CFLG <= -1 )
replace FD40DFLG = . if (FD40DFLG <= -1 )
replace FB64MOTH = . if (FB64MOTH <= -1 )
replace FC7FOTH1 = . if (FC7FOTH1 <= -1 )
replace FC7FOTH2 = . if (FC7FOTH2 <= -1 )
replace FC7FOTH3 = . if (FC7FOTH3 <= -1 )
replace FD49MOTH = . if (FD49MOTH <= -1 )
replace FD81IOTH = . if (FD81IOTH <= -1 )
replace FC23 = . if (FC23 <= -1 )
replace FC29OOTH = . if (FC29OOTH <= -1 )
replace FDAYSDCG = . if (FDAYSDCG <= -1 )
replace F_NEXTTX = . if (F_NEXTTX <= -1 )
replace F_AGEINT = . if (F_AGEINT <= -1 )
replace A73 = . if (A73 <= -1 )
replace AGE_CALC = . if (AGE_CALC <= -1 )
replace LOS = . if (LOS <= -1 )
replace TRT_DUR = . if (TRT_DUR <= -1 )
replace ALCOHOL = . if (ALCOHOL <= -1 )
replace DRUG = . if (DRUG <= -1 )
replace DRUG_ALC = . if (DRUG_ALC <= -1 )
replace TXCARE = . if (TXCARE <= -1 )
replace ABSSMPTY = . if (ABSSMPTY <= -1 )
replace QFSTRAT = . if (QFSTRAT <= -1 )
replace GROUP = . if (GROUP <= -1 )
replace FIELDPSU = . if (FIELDPSU <= -1 )
replace U_MRJ_SM = . if (U_MRJ_SM <= -1 )
replace U_PCP_SM = . if (U_PCP_SM <= -1 )
replace U_AMP_SM = . if (U_AMP_SM <= -1 )
replace U_BEN_SM = . if (U_BEN_SM <= -1 )
replace U_COC_SM = . if (U_COC_SM <= -1 )
replace U_MET_SM = . if (U_MET_SM <= -1 )
replace U_OPI_SM = . if (U_OPI_SM <= -1 )
replace U_ALCF1 = . if (U_ALCF1 <= -1 )
replace U_MRJF1 = . if (U_MRJF1 <= -1 )
replace U_PCPF1 = . if (U_PCPF1 <= -1 )
replace U_AMPF1 = . if (U_AMPF1 <= -1 )
replace U_AMPF2 = . if (U_AMPF2 <= -1 )
replace U_BENF1 = . if (U_BENF1 <= -1 )
replace U_BENF2 = . if (U_BENF2 <= -1 )
replace U_BENF3 = . if (U_BENF3 <= -1 )
replace U_BENF4 = . if (U_BENF4 <= -1 )
replace U_BENF5 = . if (U_BENF5 <= -1 )
replace U_BENF6 = . if (U_BENF6 <= -1 )
replace U_BENF7 = . if (U_BENF7 <= -1 )
replace U_BENF8 = . if (U_BENF8 <= -1 )
replace U_COCF1 = . if (U_COCF1 <= -1 )
replace U_METF1 = . if (U_METF1 <= -1 )
replace U_OPIF1 = . if (U_OPIF1 <= -1 )
replace U_OPIF2 = . if (U_OPIF2 <= -1 )
replace U_OPIF3 = . if (U_OPIF3 <= -1 )
replace U_OPIF4 = . if (U_OPIF4 <= -1 )
replace U_AMLID = . if (U_AMLID <= -1 )
replace U_CREATN = . if (U_CREATN <= -1 )
replace U_PH = . if (U_PH <= -1 )
replace U_MRJV1 = . if (U_MRJV1 <= -1 )
replace U_PCPV1 = . if (U_PCPV1 <= -1 )
replace U_AMPV1 = . if (U_AMPV1 <= -1 )
replace U_AMPV2 = . if (U_AMPV2 <= -1 )
replace U_BENV1 = . if (U_BENV1 <= -1 )
replace U_BENV2 = . if (U_BENV2 <= -1 )
replace U_BENV3 = . if (U_BENV3 <= -1 )
replace U_BENV4 = . if (U_BENV4 <= -1 )
replace U_BENV5 = . if (U_BENV5 <= -1 )
replace U_BENV6 = . if (U_BENV6 <= -1 )
replace U_BENV7 = . if (U_BENV7 <= -1 )
replace U_BENV8 = . if (U_BENV8 <= -1 )
replace U_COCV1 = . if (U_COCV1 <= -1 )
replace U_METV1 = . if (U_METV1 <= -1 )
replace U_OPIV1 = . if (U_OPIV1 <= -1 )
replace U_OPIV2 = . if (U_OPIV2 <= -1 )
replace U_OPIV3 = . if (U_OPIV3 <= -1 )
replace U_OPIV4 = . if (U_OPIV4 <= -1 )
replace U_ALCV1 = . if (U_ALCV1 <= -1.00 )
replace U_NITRIT = . if (U_NITRIT <= -1 )
replace U_ANYPOS = . if (U_ANYPOS <= -1 )
replace U_ANYDRG = . if (U_ANYDRG <= -1 )
replace U_NUMDRG = . if (U_NUMDRG <= -1 )
replace U_DTDIFF = . if (U_DTDIFF <= -1 )
replace U_RESULT = . if (U_RESULT <= -1 )
replace FB33 = . if (FB33 <= -1.00 )
replace FB38 = . if (FB38 <= -1.00 )
replace FC13 = . if (FC13 <= -1.00 )
replace FC16 = . if (FC16 <= -1.00 )
replace FD28 = . if (FD28 <= -1.00 )
replace FD31 = . if (FD31 <= -1.00 )
replace RAKFC3 = . if (RAKFC3 <= -1.0000 )
replace DIM5 = . if (DIM5 <= -1 )
replace DIM4 = . if (DIM4 <= -1 )
replace DIM3 = . if (DIM3 <= -1 )
replace DIM2 = . if (DIM2 <= -1 )
replace DIM1 = . if (DIM1 <= -1 )
replace PAIR90 = . if (PAIR90 <= -1 )
replace CAT_CLI2 = . if (CAT_CLI2 <= -1 )
replace CAT_C_D = . if (CAT_C_D <= -1 )
replace PSUTYPE2 = . if (PSUTYPE2 <= -1 )
replace CENREG = . if (CENREG <= -1 )
replace OWN = . if (OWN <= -1 )
replace VST_PSU = . if (VST_PSU <= -1 )
replace VUN_PSU = . if (VUN_PSU <= -1 )
replace MAIN_WT = . if (MAIN_WT <= -1 )
replace C3BWT0 = . if (C3BWT0 <= -1.0000 )
replace CLTYPE = . if (CLTYPE <= -1 )
replace DRUG_D81 = . if (DRUG_D81 <= -1 )
replace SELF_C31 = . if (SELF_C31 <= -1 )
replace CTRIMFLG = . if (CTRIMFLG <= -1 )
replace C3FWT0 = . if (C3FWT0 <= -1.0000 )
replace CTRMFCTR = . if (CTRMFCTR <= -1.0000 )
replace C3FWT1 = . if (C3FWT1 <= -1.0000 )
replace C3FWT2 = . if (C3FWT2 <= -1.0000 )
replace C3FWT3 = . if (C3FWT3 <= -1.0000 )
replace C3FWT4 = . if (C3FWT4 <= -1.0000 )
replace C3FWT5 = . if (C3FWT5 <= -1.0000 )
replace C3FWT6 = . if (C3FWT6 <= -1.0000 )
replace C3FWT7 = . if (C3FWT7 <= -1.0000 )
replace C3FWT8 = . if (C3FWT8 <= -1.0000 )
replace C3FWT9 = . if (C3FWT9 <= -1.0000 )
replace C3FWT10 = . if (C3FWT10 <= -1.0000 )
replace C3FWT11 = . if (C3FWT11 <= -1.0000 )
replace C3FWT12 = . if (C3FWT12 <= -1.0000 )
replace C3FWT13 = . if (C3FWT13 <= -1.0000 )
replace C3FWT14 = . if (C3FWT14 <= -1.0000 )
replace C3FWT15 = . if (C3FWT15 <= -1.0000 )
replace C3FWT16 = . if (C3FWT16 <= -1.0000 )
replace C3FWT17 = . if (C3FWT17 <= -1.0000 )
replace C3FWT18 = . if (C3FWT18 <= -1.0000 )
replace C3FWT19 = . if (C3FWT19 <= -1.0000 )
replace C3FWT20 = . if (C3FWT20 <= -1.0000 )
replace C3FWT21 = . if (C3FWT21 <= -1.0000 )
replace C3FWT22 = . if (C3FWT22 <= -1.0000 )
replace C3FWT23 = . if (C3FWT23 <= -1.0000 )
replace C3FWT24 = . if (C3FWT24 <= -1.0000 )
replace C3FWT25 = . if (C3FWT25 <= -1.0000 )
replace C3FWT26 = . if (C3FWT26 <= -1.0000 )
replace C3FWT27 = . if (C3FWT27 <= -1.0000 )
replace C3FWT28 = . if (C3FWT28 <= -1.0000 )
replace C3FWT29 = . if (C3FWT29 <= -1.0000 )
replace C3FWT30 = . if (C3FWT30 <= -1.0000 )
replace C3FWT31 = . if (C3FWT31 <= -1.0000 )
replace C3FWT32 = . if (C3FWT32 <= -1.0000 )
replace C3FWT33 = . if (C3FWT33 <= -1.0000 )
replace C3FWT34 = . if (C3FWT34 <= -1.0000 )
replace C3FWT35 = . if (C3FWT35 <= -1.0000 )
replace C3FWT36 = . if (C3FWT36 <= -1.0000 )
replace C3FWT37 = . if (C3FWT37 <= -1.0000 )
replace C3FWT38 = . if (C3FWT38 <= -1.0000 )
replace C3FWT39 = . if (C3FWT39 <= -1.0000 )
replace C3FWT40 = . if (C3FWT40 <= -1.0000 )
replace C3FWT41 = . if (C3FWT41 <= -1.0000 )
replace C3FWT42 = . if (C3FWT42 <= -1.0000 )
replace C3FWT43 = . if (C3FWT43 <= -1.0000 )
replace C3FWT44 = . if (C3FWT44 <= -1.0000 )
replace C3FWT45 = . if (C3FWT45 <= -1.0000 )
replace C3FWT46 = . if (C3FWT46 <= -1.0000 )
replace C3FWT47 = . if (C3FWT47 <= -1.0000 )
replace C3FWT48 = . if (C3FWT48 <= -1.0000 )
replace C3FWT49 = . if (C3FWT49 <= -1.0000 )
replace C3FWT50 = . if (C3FWT50 <= -1.0000 )
replace C3FWT51 = . if (C3FWT51 <= -1.0000 )
replace C3FWT52 = . if (C3FWT52 <= -1.0000 )
replace C3FWT53 = . if (C3FWT53 <= -1.0000 )
replace C3FWT54 = . if (C3FWT54 <= -1.0000 )
replace C3FWT55 = . if (C3FWT55 <= -1.0000 )
replace C3FWT56 = . if (C3FWT56 <= -1.0000 )
replace C3FWT57 = . if (C3FWT57 <= -1.0000 )
replace C3FWT58 = . if (C3FWT58 <= -1.0000 )
replace C3FWT59 = . if (C3FWT59 <= -1.0000 )
replace C3FWT60 = . if (C3FWT60 <= -1.0000 )
replace C3FWT61 = . if (C3FWT61 <= -1.0000 )
replace C3FWT62 = . if (C3FWT62 <= -1.0000 )
replace C3FWT63 = . if (C3FWT63 <= -1.0000 )
replace C3FWT64 = . if (C3FWT64 <= -1.0000 )
replace C3FWT65 = . if (C3FWT65 <= -1.0000 )
replace C3FWT66 = . if (C3FWT66 <= -1.0000 )
replace C3FWT67 = . if (C3FWT67 <= -1.0000 )
replace C3FWT68 = . if (C3FWT68 <= -1.0000 )
replace C3FWT69 = . if (C3FWT69 <= -1.0000 )
replace C3FWT70 = . if (C3FWT70 <= -1.0000 )
replace C3FWT71 = . if (C3FWT71 <= -1.0000 )
replace C3FWT72 = . if (C3FWT72 <= -1.0000 )
replace C3FWT73 = . if (C3FWT73 <= -1.0000 )
replace C3FWT74 = . if (C3FWT74 <= -1.0000 )
replace C3FWT75 = . if (C3FWT75 <= -1.0000 )
replace C3FWT76 = . if (C3FWT76 <= -1.0000 )
replace C3FWT77 = . if (C3FWT77 <= -1.0000 )
replace C3FWT78 = . if (C3FWT78 <= -1.0000 )


*/
/********************************************************************

 Section 5: Save Outfile

  This section saves out a Stata system format file.  There is no reason to
  modify it if the macros in Section 1 were specified correctly.

*********************************************************************/

save `outfile', replace

